<?xml version="1.0" encoding="UTF-8"?>

<!DOCTYPE xsl:stylesheet[
        <!ENTITY nbsp "&#160;">
]>
<xsl:stylesheet
        xmlns:xsl = "http://www.w3.org/1999/XSL/Transform"
        xmlns = "http://www.w3.org/1999/xhtml"
        xmlns:ff = "urn:CHORUS:FacturesFournisseur"
        xmlns:inv = "urn:oasis:names:specification:ubl:schema:xsd:Invoice-2"
        xmlns:avr = "urn:oasis:names:specification:ubl:schema:xsd:CreditNote-2"
        xmlns:cac = "urn:oasis:names:specification:ubl:schema:xsd:CommonAggregateComponents-2"
        xmlns:cbc = "urn:oasis:names:specification:ubl:schema:xsd:CommonBasicComponents-2"
        xmlns:cec = "urn:oasis:names:specification:ubl:schema:xsd:CommonExtensionComponents-2"
        xmlns:cur = "urn:un:unece:uncefact:codelist:specification:54217:2001"
        xmlns:uni = "urn:un:unece:uncefact:codelist:specification:66411:2001"
        xmlns:aife="urn:AIFE:Facture:Extension"
        version = "1.0">
        <xsl:output
                method = "html"
                indent = "yes"
                standalone = "yes"
                version = "1.0"/>
        <xsl:decimal-format
                name = "decformat"
                decimal-separator = ","
                grouping-separator = " "
                digit = "#"
                pattern-separator = ";"
                NaN = "NaN"
                minus-sign = "-"
                zero-digit = "0"/>
        <xsl:variable name = "pays" select = "document('../resources/iso_3166-1-a2-n3_fr.xml')"/>
        <xsl:variable name = "UNECE4461_Subset" select = "document('../resources/unece_4461_subset.xml')"/>
        <xsl:template name = "libPays">
                <xsl:param name = "cod"/>
                <xsl:choose>
                        <xsl:when test = "$pays/ISO_3166-1_List_fr/ISO_3166-1_Entry[ISO_3166-1_Alpha-2_code=$cod]/ISO_3166-1_Country_name/text()">
                                <xsl:value-of select = "$pays/ISO_3166-1_List_fr/ISO_3166-1_Entry[ISO_3166-1_Alpha-2_code=$cod]/ISO_3166-1_Country_name/text()"/>
                        </xsl:when>
                        <xsl:otherwise></xsl:otherwise>
                </xsl:choose>
        </xsl:template>
        <xsl:template name = "libPaiement">
                <xsl:param name = "code"/>
                <xsl:choose>
                        <xsl:when test = "$UNECE4461_Subset/UNECE4461_Subset_list/UNECE4461_Subset_Entry[UNECE4461_Subset_Code=$code]/UNECE4461_Subset_Description[@languageID='fr']/text()">
                                <xsl:value-of select = "$UNECE4461_Subset/UNECE4461_Subset_list/UNECE4461_Subset_Entry[UNECE4461_Subset_Code=$code]/UNECE4461_Subset_Description[@languageID='fr']/text()"/>
                        </xsl:when>
                        <xsl:otherwise></xsl:otherwise>
                </xsl:choose>
        </xsl:template>
        <xsl:template name = "slash-date">
                <xsl:param name = "datebrute"/>
                <xsl:value-of select = "substring($datebrute, 9, 2)"/>
                <xsl:text>/</xsl:text>
                <xsl:value-of select = "substring($datebrute, 6, 2)"/>
                <xsl:text>/</xsl:text>
                <xsl:value-of select = "substring($datebrute, 1, 4)"/>
        </xsl:template>

        <xsl:template name="tokenizeNotes">

                <xsl:param name="list"/>
                <xsl:param name="delimiter"/>
                <xsl:choose>
                        <xsl:when test="contains($list, $delimiter)">
                                <xsl:element name = "tr">
                                <xsl:element name = "td">
                                        <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                        <xsl:attribute name = "style">font-size:10px</xsl:attribute>
                                        <xsl:value-of select = "substring-before($list,$delimiter)"/>
                                </xsl:element>
                                </xsl:element>
                                <xsl:call-template name="tokenizeNotes">
                                        <xsl:with-param name="list" select="substring-after($list,$delimiter)"/>
                                        <xsl:with-param name="delimiter" select="$delimiter"/>
                                </xsl:call-template>
                        </xsl:when>
                        <xsl:otherwise>
                                <xsl:choose>
                                        <xsl:when test="$list = ''">
                                                <xsl:text/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                                <xsl:element name = "td">
                                                        <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                                        <xsl:attribute name = "style">font-size:10px</xsl:attribute>
                                                        <xsl:value-of select = "$list"/>
                                                </xsl:element>
                                        </xsl:otherwise>
                                </xsl:choose>
                        </xsl:otherwise>
                </xsl:choose>
        </xsl:template>  

        <xsl:template name = "EnteteFacture">
                <xsl:param name = "eltPere"/>
                <xsl:variable name = "codePaiement" select = "$eltPere/cac:PaymentMeans/cbc:PaymentMeansCode/text()"/>
                <xsl:variable name = "numCompte" select = "$eltPere/cac:PaymentMeans/cac:PayeeFinancialAccount/cbc:ID/text()"/>
                <xsl:element name = "center">
                        <xsl:element name = "p">
                                <xsl:attribute name = "class">titre0</xsl:attribute>
                                <xsl:choose>
                                        <xsl:when test = "$eltPere/cbc:InvoiceTypeCode = 380">Facture</xsl:when>
                                        <xsl:when test = "$eltPere/cbc:InvoiceTypeCode = 382">Facture</xsl:when>										
                                        <xsl:when test = "$eltPere/cbc:InvoiceTypeCode = 383">Facture</xsl:when>
                                        <xsl:when test = "$eltPere/cbc:InvoiceTypeCode = 384">Facture</xsl:when>
                                        <xsl:when test = "$eltPere/cbc:InvoiceTypeCode = 385">Facture</xsl:when>
										<xsl:when test = "$eltPere/cbc:InvoiceTypeCode = 386">Facture</xsl:when>                                        
                                        <xsl:when test = "$eltPere/cbc:InvoiceTypeCode = 381">Avoir</xsl:when>
                                        <xsl:otherwise>Avoir</xsl:otherwise>
                                </xsl:choose>
                                &nbsp;
                                <xsl:value-of select = "$eltPere/cbc:ID"/>
                                <xsl:if test = "$eltPere/cbc:IssueDate">
                                        du&nbsp;
                                        <xsl:call-template name = "slash-date">
                                                <xsl:with-param name = "datebrute" select = "$eltPere/cbc:IssueDate"/>
                                        </xsl:call-template>
                                </xsl:if>
                                
                        	<xsl:if test = "$eltPere/cbc:InvoiceTypeCode/text() != '380' and $eltPere/cac:BillingReference/cac:InvoiceDocumentReference/cbc:ID/text()">
                               	                 &nbsp;portant sur la facture :&nbsp;
                               	                         <xsl:value-of select = "$eltPere/cac:BillingReference/cac:InvoiceDocumentReference/cbc:ID/text()"/>
                        	</xsl:if>

                                <xsl:if test="$eltPere/cac:InvoicePeriod/cbc:StartDate"> &nbsp;-&nbsp;Période de
                                        facturation du&nbsp; <xsl:call-template name="slash-date">
                                                <xsl:with-param name="datebrute"
                                                        select="$eltPere/cac:InvoicePeriod/cbc:StartDate"/>
                                        </xsl:call-template>
                                </xsl:if>
                                <xsl:if test="$eltPere/cac:InvoicePeriod/cbc:EndDate"> &nbsp;au&nbsp;
                                        <xsl:call-template name="slash-date">
                                                <xsl:with-param name="datebrute"
                                                        select="$eltPere/cac:InvoicePeriod/cbc:EndDate"/>
                                        </xsl:call-template>
								</xsl:if> 

                                <xsl:if test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode">
								<br/>
								<xsl:element name="tr">
                                        <xsl:element name="td">
												<xsl:attribute name = "class">titre0</xsl:attribute>
                                                <xsl:value-of select="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode"/> 
                                                <xsl:choose>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A1'">&nbsp;: Dépôt par
                                                                un fournisseur d'une facture</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A2'">&nbsp;: Dépôt par
                                                                un fournisseur d'une facture déjà payée</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A3'">&nbsp;: Dépôt par
                                                                un fournisseur d'un mémoire de frais de justice</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A4'">&nbsp;: Dépôt par
                                                                un fournisseur d'un projet de décompte mensuel</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A5'">&nbsp;: Dépôt par
                                                                un fournisseur d'un état d'acompte</xsl:when>
														<xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A6'">&nbsp;: Dépôt par
                                                                    un fournisseur d'un état d'acompte validé</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A7'">&nbsp;: Dépôt par
                                                                un fournisseur d'un projet de décompte final</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A8'">&nbsp;: Dépôt par
                                                                un fournisseur d'un décompte général signé</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A9'">&nbsp;: Dépôt par
                                                                un sous-traitant d'une demande de paiement</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A10'">&nbsp;: Dépôt par
                                                                un sous-traitant d'une demande de paiement dans le cadre des marchés de travaux</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A12'">&nbsp;: Dépôt par
                                                                un cotraitant d'une facture</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A13'">&nbsp;: Dépôt par
                                                                un cotraitant d'un projet de décompte mensuel</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A14'">&nbsp;: Dépôt par
                                                                un cotraitant d'un projet de décompte final</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A15'">&nbsp;: Dépôt par
                                                                une MOE d'un état d'acompte</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A16'">&nbsp;: Dépôt par
                                                                une MOE d'un état d'acompte validé</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A17'">&nbsp;: Dépôt par
                                                                une MOE d'un projet de décompte général</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A18'">&nbsp;: Dépôt par
                                                                une MOE d'un décompte général</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A19'">&nbsp;: Dépôt par
                                                                une MOA d'un état d'acompte validé</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A20'">&nbsp;: Dépôt par
                                                                une MOA d'un décompte général</xsl:when>
                                                        <xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A21'">&nbsp;: Dépôt par
                                                                un bénéficiaire d'une demande de remboursement de la TIC</xsl:when>
														<xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A22'">&nbsp;: Dépôt par
                                                                un fournisseur d'un projet de décompte général tacite</xsl:when>
														<xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A23'">&nbsp;: Dépôt par
                                                                un fournisseur d'un décompte général et définitif dans le cadre d'une procédure tacite</xsl:when>
														<xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A24'">&nbsp;: Dépôt par
                                                                une MOE d'un décompte général et définitif dans le cadre d'une procédure tacite tacite</xsl:when>
														<xsl:when test="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/aife:FactureExtension/aife:CategoryCode = 'A25'">&nbsp;: Dépôt par
                                                                une MOA d'un décompte général et définitif tacite</xsl:when>
                                                        <xsl:otherwise>&nbsp;A1 : Dépôt par un fournisseur d'une facture</xsl:otherwise>
                                                </xsl:choose>
                                        </xsl:element>
                                </xsl:element>
                                </xsl:if>
								 
								
								<xsl:for-each select="$eltPere/cec:UBLExtensions/cec:UBLExtension/cec:ExtensionContent/*">
										<xsl:if test = "name(.) = 'CategoryCode'">
											<br/>										
											<xsl:element name="tr">
												<xsl:element name="td">
													<xsl:attribute name = "class">titre0</xsl:attribute>
													<xsl:value-of select="./text()"/> 
													<xsl:choose>
                                                        <xsl:when test="./text() = 'A1'">&nbsp;: Dépôt par
                                                                un fournisseur d'une facture</xsl:when>
                                                        <xsl:when test="./text() = 'A2'">&nbsp;: Dépôt par
                                                                un fournisseur d'une facture déjà payée</xsl:when>
                                                        <xsl:when test="./text() = 'A3'">&nbsp;: Dépôt par
                                                                un fournisseur d'un mémoire de frais de justice</xsl:when>
                                                        <xsl:when test="./text() = 'A4'">&nbsp;: Dépôt par
                                                                un fournisseur d'un projet de décompte mensuel</xsl:when>
                                                        <xsl:when test="./text() = 'A5'">&nbsp;: Dépôt par
                                                                un fournisseur d'un état d'acompte</xsl:when>
														<xsl:when test="./text() = 'A6'">&nbsp;: Dépôt par
                                                                    un fournisseur d'un état d'acompte validé</xsl:when>
                                                        <xsl:when test="./text() = 'A7'">&nbsp;: Dépôt par
                                                                un fournisseur d'un projet de décompte final</xsl:when>
                                                        <xsl:when test="./text() = 'A8'">&nbsp;: Dépôt par
                                                                un fournisseur d'un décompte général signé</xsl:when>
                                                        <xsl:when test="./text() = 'A9'">&nbsp;: Dépôt par
                                                                un sous-traitant d'une demande de paiement</xsl:when>
                                                        <xsl:when test="./text() = 'A10'">&nbsp;: Dépôt par
                                                                un sous-traitant d'une demande de paiement dans le cadre des marchés de travaux</xsl:when>
                                                        <xsl:when test="./text() = 'A12'">&nbsp;: Dépôt par
                                                                un cotraitant d'une facture</xsl:when>
                                                        <xsl:when test="./text() = 'A13'">&nbsp;: Dépôt par
                                                                un cotraitant d'un projet de décompte mensuel</xsl:when>
                                                        <xsl:when test="./text() = 'A14'">&nbsp;: Dépôt par
                                                                un cotraitant d'un projet de décompte final</xsl:when>
                                                        <xsl:when test="./text() = 'A15'">&nbsp;: Dépôt par
                                                                une MOE d'un état d'acompte</xsl:when>
                                                        <xsl:when test="./text() = 'A16'">&nbsp;: Dépôt par
                                                                une MOE d'un état d'acompte validé</xsl:when>
                                                        <xsl:when test="./text() = 'A17'">&nbsp;: Dépôt par
                                                                une MOE d'un projet de décompte général</xsl:when>
                                                        <xsl:when test="./text() = 'A18'">&nbsp;: Dépôt par
                                                                une MOE d'un décompte général</xsl:when>
                                                        <xsl:when test="./text() = 'A19'">&nbsp;: Dépôt par
                                                                une MOA d'un état d'acompte validé</xsl:when>
                                                        <xsl:when test="./text() = 'A20'">&nbsp;: Dépôt par
                                                                une MOA d'un décompte général</xsl:when>
                                                        <xsl:when test="./text() = 'A21'">&nbsp;: Dépôt par
                                                                un bénéficiaire d'une demande de remboursement de la TIC</xsl:when>
														<xsl:when test="./text() = 'A22'">&nbsp;: Dépôt par
                                                                un fournisseur d'un projet de décompte général tacite</xsl:when>
														<xsl:when test="./text() = 'A23'">&nbsp;: Dépôt par
                                                                un fournisseur d'un décompte général et définitif dans le cadre d'une procédure tacite</xsl:when>
														<xsl:when test="./text() = 'A24'">&nbsp;: Dépôt par
                                                                une MOE d'un décompte général et définitif dans le cadre d'une procédure tacite tacite</xsl:when>
														<xsl:when test="./text() = 'A25'">&nbsp;: Dépôt par
                                                                une MOA d'un décompte général et définitif tacite</xsl:when>
														<xsl:otherwise>&nbsp;</xsl:otherwise>
													</xsl:choose>
												</xsl:element>
											</xsl:element>
										</xsl:if>	
									</xsl:for-each>
                       </xsl:element>
                </xsl:element>

		
 					
   
                
                <xsl:element name = "table">
                        <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                        <xsl:element name = "tr">
                                <xsl:element name = "th">
                                        <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                        Récapitulatif
                                </xsl:element>
                        </xsl:element>
                        <xsl:element name = "tr">
                                <xsl:element name = "td">
                                        <xsl:attribute name = "style">padding: 15px</xsl:attribute>
                                        <xsl:element name = "table">
                                                <xsl:attribute name = "width">100%</xsl:attribute>
                                                <xsl:element name = "colgroup">
                                                        <xsl:element name = "col">
                                                                <xsl:attribute name = "width">50%</xsl:attribute>
                                                        </xsl:element>
                                                        <xsl:element name = "col">
                                                                <xsl:attribute name = "width">50%</xsl:attribute>
                                                        </xsl:element>
                                                </xsl:element>
                                                <xsl:element name = "tr">
                                                        <xsl:element name = "td">
                                                                <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                                                Total HT
                                                                <xsl:if test = "$eltPere/cac:LegalMonetaryTotal/cbc:TaxExclusiveAmount/@currencyID">
                                                                        &nbsp;(
                                                                        <xsl:value-of select = "$eltPere/cac:LegalMonetaryTotal/cbc:TaxExclusiveAmount/@currencyID"/>
                                                                        )
                                                                </xsl:if>
                                                        </xsl:element>
                                                        <xsl:element name = "td">
                                                                <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                                                <xsl:attribute name = "style">text-align: right;</xsl:attribute>
                                                                <xsl:call-template name = "number">
                                                                        <xsl:with-param name = "num" select = "$eltPere/cac:LegalMonetaryTotal/cbc:TaxExclusiveAmount"/>
                                                                </xsl:call-template>
                                                        </xsl:element>
                                                </xsl:element>
                                                <xsl:element name = "tr">
                                                        <xsl:element name = "td">
                                                                <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                                                Total
                                                                Taxes
                                                                <xsl:if test = "$eltPere/cac:TaxTotal/cbc:TaxAmount/@currencyID">
                                                                        &nbsp;(
                                                                        <xsl:value-of select = "$eltPere/cac:TaxTotal/cbc:TaxAmount/@currencyID"/>
                                                                        )
                                                                </xsl:if>
                                                        </xsl:element>
                                                        <xsl:element name = "td">
                                                                <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                                                <xsl:attribute name = "style">text-align: right;</xsl:attribute>
                                                                <xsl:call-template name = "number">
                                                                        <xsl:with-param name = "num" select = "$eltPere/cac:TaxTotal/cbc:TaxAmount"/>
                                                                </xsl:call-template>
                                                        </xsl:element>
                                                </xsl:element>
                                                <!--Répartition Taxes -->
                                                <xsl:if test = "$eltPere/cac:TaxTotal/cac:TaxSubtotal">
                                                        <xsl:element name = "tr">
                                                                <xsl:element name = "td">
                                                                        <xsl:attribute name = "colspan">2</xsl:attribute>
                                                                        <xsl:attribute name = "style">padding-left: 20px</xsl:attribute>
                                                                        <xsl:element name = "table">
                                                                                <xsl:attribute name = "class">EnteteSite</xsl:attribute>
                                                                                <xsl:element name = "tr">
                                                                                        <xsl:element name = "td">
                                                                                                <xsl:attribute name = "class">EnteteSite</xsl:attribute>
                                                                                                <xsl:element name = "b">Répartition des taxes</xsl:element>
                                                                                        </xsl:element>
                                                                                </xsl:element>
                                                                        </xsl:element>
                                                                        <xsl:element name = "table">
                                                                                <xsl:attribute name = "width">100%</xsl:attribute>
                                                                                <xsl:attribute name = "style">
                                                                                        bordered
                                                                                        collapsed
                                                                                </xsl:attribute>
                                                                                <xsl:attribute name = "cellpadding">0</xsl:attribute>
                                                                                <xsl:attribute name = "cellspacing">2</xsl:attribute>

                                                                                <xsl:element name = "thead">
                                                                                        <xsl:element name = "tr">
                                                                                                <xsl:element name = "th">
                                                                                                        <xsl:attribute name = "class">RecapSousTotaux</xsl:attribute>
                                                                                                        Type Taxe
                                                                                                </xsl:element>
                                                                                                <xsl:element name = "th">
                                                                                                        <xsl:attribute name = "class">RecapSousTotaux</xsl:attribute>
                                                                                                        Taux Taxe
                                                                                                </xsl:element>
                                                                                                <xsl:element name = "th">
                                                                                                        <xsl:attribute name = "class">RecapSousTotaux</xsl:attribute>
                                                                                                        Montant HT
                                                                                                </xsl:element>
                                                                                                <xsl:element name = "th">
                                                                                                        <xsl:attribute name = "class">RecapSousTotaux</xsl:attribute>
                                                                                                        Montant Taxe
                                                                                                </xsl:element>

                                                                                        </xsl:element>
                                                                                </xsl:element>
                                                                                <xsl:element name = "tbody">
                                                                                        <xsl:for-each select = "$eltPere/cac:TaxTotal/cac:TaxSubtotal">
                                                                                                <xsl:element name = "tr">
                                                                                                        <xsl:element name = "td">
                                                                                                                <xsl:attribute name = "class">top</xsl:attribute>
                                                                                                                <xsl:attribute name = "class">normal</xsl:attribute>
                                                                                                                <xsl:value-of select = "./cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode/text()"/>
                                                                                                                &nbsp;(
                                                                                                                <xsl:value-of select = "./cbc:TaxAmount/@currencyID"/>
                                                                                                                )
                                                                                                        </xsl:element>
                                                                                                        <xsl:element name = "td">
                                                                                                                <xsl:attribute name = "class">top</xsl:attribute>
                                                                                                                <xsl:attribute name = "class">right</xsl:attribute>
                                                                                                                <xsl:call-template name = "number">
                                                                                                                        <xsl:with-param name = "num" select = "./cbc:Percent/text()"/>
                                                                                                                </xsl:call-template>
                                                                                                        </xsl:element>
                                                                                                        <xsl:element name = "td">
                                                                                                                <xsl:attribute name = "class">top</xsl:attribute>
                                                                                                                <xsl:attribute name = "class">right</xsl:attribute>
                                                                                                                <xsl:call-template name = "number">
                                                                                                                        <xsl:with-param name = "num" select = "./cbc:TaxableAmount/text()"/>
                                                                                                                </xsl:call-template>
                                                                                                        </xsl:element>
                                                                                                        <xsl:element name = "td">
                                                                                                                <xsl:attribute name = "class">top</xsl:attribute>
                                                                                                                <xsl:attribute name = "class">right</xsl:attribute>
                                                                                                                <xsl:call-template name = "number">
                                                                                                                        <xsl:with-param name = "num" select = "./cbc:TaxAmount/text()"/>
                                                                                                                </xsl:call-template>
                                                                                                        </xsl:element>

                                                                                                </xsl:element>
                                                                                        </xsl:for-each>
                                                                                </xsl:element>
                                                                        </xsl:element>
                                                                </xsl:element>
                                                        </xsl:element>
                                                </xsl:if>
                                                <xsl:element name = "tr">
                                                        <xsl:element name = "td">&nbsp;</xsl:element>
                                                </xsl:element>

                                                <xsl:if test="$eltPere/cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cbc:TaxExemptionReason/text()">
                                                        <xsl:element name="tr">
                                                                <xsl:element name="td">
                                                                        <xsl:attribute name="class">Recapitulatif</xsl:attribute> Motif
                                                                        éxonération : </xsl:element>
                                                                <xsl:element name="td">
                                                                        <xsl:attribute name="class">Recapitulatif</xsl:attribute>
                                                                        <xsl:attribute name="style">text-align: right;</xsl:attribute>
                                                                        <xsl:value-of
                                                                                select="$eltPere/cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cbc:TaxExemptionReason/text()"
                                                                        />
                                                                </xsl:element>
                                                        </xsl:element>
                                                </xsl:if>
                                                
                                                <xsl:if test = "$eltPere/cac:LegalMonetaryTotal/cbc:AllowanceTotalAmount">
                                                        <xsl:element name = "tr">
                                                                <xsl:element name = "td">
                                                                        <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                                                        Total
                                                                        Remises
                                                                        <xsl:if test = "$eltPere/cac:LegalMonetaryTotal/cbc:AllowanceTotalAmount/@currencyID">
                                                                                &nbsp;(
                                                                                <xsl:value-of select = "$eltPere/cac:LegalMonetaryTotal/cbc:AllowanceTotalAmount/@currencyID"/>
                                                                                )
                                                                        </xsl:if>
                                                                </xsl:element>
                                                                <xsl:element name = "td">
                                                                        <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                                                        <xsl:attribute name = "style">text-align: right;</xsl:attribute>
                                                                        <xsl:call-template name = "number">
                                                                                <xsl:with-param name = "num" select = "$eltPere/cac:LegalMonetaryTotal/cbc:AllowanceTotalAmount/text()"/>
                                                                        </xsl:call-template>
                                                                </xsl:element>
                                                        </xsl:element>
                                                </xsl:if>
												 <xsl:if
                                                        test="$eltPere/cac:LegalMonetaryTotal/cbc:ChargeTotalAmount and not(string-length(/inv:Invoice/cac:LegalMonetaryTotal/cbc:ChargeTotalAmount/text())=0)">
                                                        <xsl:element name="tr">
                                                                <xsl:element name="td">
                                                                        <xsl:attribute name="class">Recapitulatif</xsl:attribute>
                                                                        Montant charges <xsl:if
                                                                                test="$eltPere/cac:LegalMonetaryTotal/cbc:ChargeTotalAmount/@currencyID"
                                                                                > &nbsp;(<xsl:value-of
                                                                                        select="$eltPere/cac:LegalMonetaryTotal/cbc:ChargeTotalAmount/@currencyID"
                                                                                />) </xsl:if>
                                                                </xsl:element>
                                                                <xsl:element name="td">
                                                                        <xsl:attribute name="class">Recapitulatif</xsl:attribute>
                                                                        <xsl:attribute name="style">text-align: right;</xsl:attribute>
                                                                        <xsl:call-template name="number">
                                                                                <xsl:with-param name="num"
                                                                                        select="$eltPere/cac:LegalMonetaryTotal/cbc:ChargeTotalAmount"
                                                                                />
                                                                        </xsl:call-template>
                                                                </xsl:element>
                                                        </xsl:element>
                                                </xsl:if>   
                                                <xsl:if test = "$eltPere/cac:AllowanceCharge">
                                                        <xsl:element name = "tr">
                                                                <xsl:element name = "td">
                                                                        <xsl:attribute name = "colspan">2</xsl:attribute>
                                                                        <xsl:attribute name = "style">padding-left: 20px</xsl:attribute>
                                                                        <xsl:element name = "table">
                                                                                <xsl:attribute name = "class">EnteteSite</xsl:attribute>
                                                                                <xsl:element name = "tr">
                                                                                        <xsl:element name = "td">
                                                                                                <xsl:attribute name = "class">EnteteSite</xsl:attribute>
                                                                                                <xsl:element name = "b">Répartition des remises et charges</xsl:element>
                                                                                        </xsl:element>
                                                                                </xsl:element>
                                                                        </xsl:element>
                                                                        <xsl:element name = "table">
                                                                                <xsl:attribute name = "width">100%</xsl:attribute>
                                                                                <xsl:attribute name = "style">
                                                                                        bordered
                                                                                        collapsed
                                                                                </xsl:attribute>
                                                                                <xsl:attribute name = "cellpadding">0</xsl:attribute>
                                                                                <xsl:attribute name = "cellspacing">2</xsl:attribute>
                                                                                <xsl:element name = "thead">
                                                                                        <xsl:element name = "tr">
                                                                                                <xsl:element name = "th">
                                                                                                        <xsl:attribute name = "class">RecapSousTotaux</xsl:attribute>
                                                                                                        Type 
                                                                                                </xsl:element>
                                                                                                <xsl:element name = "th">
                                                                                                        <xsl:attribute name = "class">RecapSousTotaux</xsl:attribute>
                                                                                                        Montant 
                                                                                                </xsl:element>
                                                                                        </xsl:element>
                                                                                </xsl:element>
                                                                                <xsl:element name = "tbody">
                                                                                        <xsl:for-each select = "$eltPere/cac:AllowanceCharge">
                                                                                                <xsl:element name = "tr">
                                                                                                        <xsl:element name = "td">
                                                                                                                <xsl:attribute name = "class">top</xsl:attribute>
                                                                                                                <xsl:attribute name = "class">normal</xsl:attribute>
                                                                                                                
                                                                                                                <xsl:if test = "./cbc:ChargeIndicator = 'false'">
                                                                                                                        Remise&nbsp;:&nbsp; 
                                                                                                                </xsl:if>																												
                                                                                                                <xsl:if test = "./cbc:ChargeIndicator = 'true'">
                                                                                                                        Charge&nbsp;:&nbsp; 
                                                                                                                </xsl:if>
                                                                                                                
                                                                                                                <xsl:value-of select = "./cbc:AllowanceChargeReason/text()"/>
                                                                                                                &nbsp;(
                                                                                                                <xsl:value-of select = "./cbc:Amount/@currencyID"/>
                                                                                                                )
                                                                                                        </xsl:element>
                                                                                                        <xsl:element name = "td">
                                                                                                                <xsl:attribute name = "class">top</xsl:attribute>
                                                                                                                <xsl:attribute name = "class">right</xsl:attribute>
                                                                                                                <xsl:call-template name = "number">
                                                                                                                        <xsl:with-param name = "num" select = "./cbc:Amount/text()"/>
                                                                                                                </xsl:call-template>
                                                                                                        </xsl:element>
                                                                                                </xsl:element>
                                                                                        </xsl:for-each>
                                                                                </xsl:element>
                                                                        </xsl:element>
                                                                </xsl:element>
                                                        </xsl:element>
                                                </xsl:if>
                                                <xsl:element name = "tr">
                                                        <xsl:element name = "td">&nbsp;</xsl:element>
                                                </xsl:element>
                                                <xsl:element name = "tr">
                                                        <xsl:element name = "td">
                                                                <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                                                Total TTC
                                                                <xsl:if test = "$eltPere/cac:LegalMonetaryTotal/cbc:TaxInclusiveAmount/@currencyID">
                                                                        &nbsp;(
                                                                        <xsl:value-of select = "$eltPere/cac:LegalMonetaryTotal/cbc:TaxInclusiveAmount/@currencyID"/>
                                                                        )
                                                                </xsl:if>
                                                        </xsl:element>
                                                        <xsl:element name = "td">
                                                                <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                                                <xsl:attribute name = "style">text-align: right;</xsl:attribute>
                                                                <xsl:call-template name = "number">
                                                                        <xsl:with-param name = "num" select = "$eltPere/cac:LegalMonetaryTotal/cbc:TaxInclusiveAmount"/>
                                                                </xsl:call-template>
                                                        </xsl:element>
                                                </xsl:element>
                                                
                                                                                            
                                                
                                                <xsl:if test = "$eltPere/cac:LegalMonetaryTotal/cbc:PrepaidAmount and not(string-length($eltPere/cac:LegalMonetaryTotal/cbc:PrepaidAmount/text())=0)">
                                                        <xsl:element name = "tr">
                                                                <xsl:element name = "td">
                                                                        <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                                                        A
                                                                        déduire (déjà payé)
                                                                        <xsl:if test = "$eltPere/cac:LegalMonetaryTotal/cbc:PrepaidAmount/@currencyID">
                                                                                &nbsp;(
                                                                                <xsl:value-of select = "$eltPere/cac:LegalMonetaryTotal/cbc:PrepaidAmount/@currencyID"/>
                                                                                )
                                                                        </xsl:if>
                                                                </xsl:element>
                                                                <xsl:element name = "td">
                                                                        <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                                                        <xsl:attribute name = "style">text-align: right;</xsl:attribute>
                                                                        <xsl:call-template name = "number">
                                                                                <xsl:with-param name = "num" select = "$eltPere/cac:LegalMonetaryTotal/cbc:PrepaidAmount"/>
                                                                        </xsl:call-template>
                                                                </xsl:element>
                                                        </xsl:element>
                                                </xsl:if>
                                                <xsl:if test = "$eltPere/cac:LegalMonetaryTotal/cbc:PayableAmount and not(string-length($eltPere/cac:LegalMonetaryTotal/cbc:PayableAmount/text())=0)">
                                                        <xsl:element name = "tr">
                                                                <xsl:element name = "td">
                                                                        <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                                                        A
                                                                        payer
                                                                        <xsl:if test = "$eltPere/cac:LegalMonetaryTotal/cbc:PayableAmount/@currencyID">
                                                                                &nbsp;(
                                                                                <xsl:value-of select = "$eltPere/cac:LegalMonetaryTotal/cbc:PayableAmount/@currencyID"/>
                                                                                )
                                                                        </xsl:if>
                                                                </xsl:element>
                                                                <xsl:element name = "td">
                                                                        <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                                                        <xsl:attribute name = "style">text-align: right;</xsl:attribute>
                                                                        <xsl:call-template name = "number">
                                                                                <xsl:with-param name = "num" select = "$eltPere/cac:LegalMonetaryTotal/cbc:PayableAmount"/>
                                                                        </xsl:call-template>
                                                                </xsl:element>
                                                        </xsl:element>
                                                </xsl:if>
                                        </xsl:element>
                                </xsl:element>
                        </xsl:element>
                </xsl:element>
                <xsl:element name = "table">
                        <xsl:if test = "count($eltPere/cbc:Note) > 0">
                                                                <xsl:element name = "tr">
                                        <xsl:element name = "td">&nbsp;</xsl:element>
                                </xsl:element>
                                <xsl:for-each select = "$eltPere/cbc:Note">
                                        <xsl:element name = "tr">
                                                        <xsl:call-template name="tokenizeNotes">
                                                                <xsl:with-param name="list" select="./text()"/>
                                                                <xsl:with-param name="delimiter" select="'§'"/>
                                                        </xsl:call-template>
                                        </xsl:element>
                                </xsl:for-each>
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">&nbsp;</xsl:element>
                                </xsl:element>
                        </xsl:if>

                        
                        <xsl:if test = "$codePaiement">
                        <xsl:element name = "tr">
                                <xsl:element name = "td">
                                        <xsl:attribute name = "style">font-size:12px</xsl:attribute>
										Paiement par&nbsp;
                                        <xsl:call-template name = "libPaiement">
                                                <xsl:with-param name = "code" select = "$codePaiement"/>
                                        </xsl:call-template>
                                        <xsl:choose>
                                                <xsl:when test = "($codePaiement='49' or $codePaiement='31'  or $codePaiement='30') and $numCompte">
                                                        <xsl:choose>
                                                                <xsl:when test = "$eltPere/cac:PaymentMeans/cbc:PaymentChannelCode/text()='IBAN'">&nbsp;sur le compte IBAN (BIC) :</xsl:when>
                                                                <xsl:otherwise>&nbsp;sur le compte :</xsl:otherwise>
                                                        </xsl:choose>
                                                </xsl:when>
                                                <xsl:otherwise/>
                                        </xsl:choose>
                                        <xsl:if test = "$codePaiement='49' or $codePaiement='31' or $codePaiement='30'">
                                                <xsl:choose>
                                                        <xsl:when test = "$numCompte">
                                                                <xsl:choose>
                                                                        <xsl:when test = "$eltPere/cac:PaymentMeans/cac:PayeeFinancialAccount/cac:FinancialInstitutionBranch/cbc:ID">
                                                                                <xsl:value-of select = "$numCompte"/>
                                                                                (
                                                                                <xsl:value-of select = "$eltPere/cac:PaymentMeans/cac:PayeeFinancialAccount/cac:FinancialInstitutionBranch/cbc:ID"/>
                                                                                )
                                                                        </xsl:when>
                                                                        <xsl:otherwise>
                                                                                <xsl:value-of select = "$numCompte"/>
                                                                        </xsl:otherwise>
                                                                </xsl:choose>
                                                        </xsl:when>
                                                        <xsl:otherwise></xsl:otherwise>
                                                </xsl:choose>
                                        </xsl:if>
                                </xsl:element>
                        </xsl:element>
                        </xsl:if>

                        <xsl:if test = "$eltPere/cac:PaymentMeans/cbc:PaymentDueDate">
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">
                                                <xsl:attribute name = "style">font-size:12px</xsl:attribute>
                                                <xsl:choose>
                                                        <xsl:when test = "$codePaiement='49'">
                                                                Cette somme sera prélevée à partir
                                                                du :
                                                        </xsl:when>
                                                        <xsl:otherwise>Nous vous remercions de votre règlement avant le :</xsl:otherwise>
                                                </xsl:choose>
                                                <xsl:call-template name = "slash-date">
                                                        <xsl:with-param name = "datebrute" select = "$eltPere/cac:PaymentMeans/cbc:PaymentDueDate/text()"/>
                                                </xsl:call-template>
                                        </xsl:element>
                                </xsl:element>
                        </xsl:if>
                        <xsl:element name = "tr">
                                <xsl:element name = "td">&nbsp;</xsl:element>
                        </xsl:element>
                        
                        <xsl:element name = "tr">
                                <xsl:element name = "td">
                                        <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                        <xsl:attribute name = "style">font-size:10px</xsl:attribute>
                                        <xsl:value-of select = "$eltPere/cac:PaymentMeans/cbc:InstructionNote/text()"/>
                                </xsl:element>
                        </xsl:element>
                        <xsl:for-each select="$eltPere/cac:PaymentTerms/cbc:Note">
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">
                                                <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                                <xsl:attribute name = "style">font-size:10px</xsl:attribute>
                                                <xsl:value-of select = "./text()"/>
                                        </xsl:element>
                                </xsl:element>
                         </xsl:for-each>
                </xsl:element>
        </xsl:template>
        <xsl:template name = "Entete">
                <xsl:param name = "eltPere"/>
                <xsl:element name = "br"/>
                <xsl:element name = "table">
                        <xsl:attribute name = "width">100%</xsl:attribute>
                        <xsl:attribute name = "cellpadding">0</xsl:attribute>
                        <xsl:attribute name = "cellspacing">0</xsl:attribute>
                        <xsl:element name = "colgroup">
                                <xsl:element name = "col">
                                        <xsl:attribute name = "width">48%</xsl:attribute>
                                </xsl:element>
                                <xsl:element name = "col">
                                        <xsl:attribute name = "width">4%</xsl:attribute>
                                </xsl:element>
                                <xsl:element name = "col">
                                        <xsl:attribute name = "width">48%</xsl:attribute>
                                </xsl:element>
                        </xsl:element>
                        <xsl:element name = "tr">
                                <xsl:element name = "td">
                                        <xsl:attribute name = "class">top</xsl:attribute>
                                        <xsl:element name = "table">
                                                <xsl:attribute name = "class">EnteteFournisseur</xsl:attribute>
                                                <xsl:element name = "tr">
                                                        <xsl:element name = "th">
                                                                <xsl:attribute name = "class">EnteteFournisseur</xsl:attribute>
                                                                Emetteur
                                                        </xsl:element>
                                                </xsl:element>
                                                <xsl:element name = "tr">
                                                        <xsl:element name = "td">
                                                                <xsl:call-template name = "EntiteJuridique">
                                                                        <xsl:with-param name="eltPere" select="$eltPere"/>
                                                                </xsl:call-template>
                                                        </xsl:element>
                                                </xsl:element>
                                                <xsl:element name = "tr">
                                                        <xsl:element name = "td">
                                                                <xsl:call-template name = "EntiteCommercial">
                                                                        <xsl:with-param name="eltPere" select="$eltPere"/>
                                                                </xsl:call-template>

                                                                <xsl:call-template name = "InformationsContactEntiteCommercial">
                                                                        <xsl:with-param name="eltPere" select="$eltPere"/>
                                                                </xsl:call-template>
                                                                
                                                                <xsl:call-template name = "InformationsFournisseur">
                                                                        <xsl:with-param name="eltPere" select="$eltPere"/>
                                                                </xsl:call-template>
                                                        </xsl:element>
                                                </xsl:element>
                                                <xsl:element name = "tr">
                                                        <xsl:element name = "td">
                                                                <xsl:call-template name = "ContactFournisseur">
                                                                        <xsl:with-param name="eltPere" select="$eltPere"/>
                                                                </xsl:call-template>
                                                        </xsl:element>
                                                </xsl:element>
                                                <xsl:element name = "tr">
                                                        <xsl:element name = "td">
                                                                <xsl:call-template name = "EntiteValideur">
                                                                        <xsl:with-param name="eltPere" select="$eltPere"/>
                                                                </xsl:call-template>
                                                        </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:element>
                                <xsl:element name = "td">&nbsp;</xsl:element>
                                <xsl:element name = "td">
                                        <xsl:attribute name = "class">top</xsl:attribute>
                                        <xsl:element name = "table">
                                                <xsl:attribute name = "style">width: 100%</xsl:attribute>
                                                <xsl:element name = "tr">
                                                        <xsl:element name = "td">
                                                                <xsl:call-template name = "EnteteClient">
                                                                        <xsl:with-param name="eltPere" select="$eltPere"/>
                                                                </xsl:call-template>
                                                        </xsl:element>
                                                </xsl:element>
                                                <xsl:element name = "tr">
                                                        <xsl:element name = "td">&nbsp;</xsl:element>
                                                </xsl:element>
                                                
                                                <xsl:element name="tr">
                                                        <xsl:element name="td">
                                                                <xsl:call-template name="EnteteServiceRecepteur">
                                                                        <xsl:with-param name="eltPere" select="$eltPere"/>
                                                                </xsl:call-template>
                                                        </xsl:element>
                                                </xsl:element>
                                                
                                                <xsl:element name="tr">
                                                        <xsl:element name="td">
                                                                <xsl:call-template name="EnteteEncaisseur">
                                                                        <xsl:with-param name="eltPere" select="$eltPere"/>
                                                                </xsl:call-template>
                                                        </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:element>
                        </xsl:element>
                </xsl:element>
        </xsl:template>
        <xsl:template name = "EntiteJuridique">
                <xsl:param name = "eltPere"/>
                <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity">
                        <xsl:element name = "table">
                                <xsl:attribute name = "class">EnteteFournisseur</xsl:attribute>
                                <xsl:element name = "tr">
                                        <xsl:element name = "th">
                                                <xsl:attribute name = "class">EnteteFournisseur</xsl:attribute>
                                                Entité&nbsp;Juridique
                                        </xsl:element>
                                </xsl:element>
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">
                                                <xsl:element name = "b">
                                                        <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName"/>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:element>
                                <xsl:for-each select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cac:AddressLine">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        <xsl:value-of select = "cbc:Line"/> 
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:for-each>
				<xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:StreetName/text()">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:StreetName"/>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">
                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:PostalZone"/>
                                                &nbsp;
                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:CityName"/>
                                        </xsl:element>
                                </xsl:element>
                                
                                <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cac:Country/cbc:IdentificationCode">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        <xsl:call-template name = "libPays">
                                                                <xsl:with-param name = "cod" select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cac:Country/cbc:IdentificationCode"/>
                                                        </xsl:call-template>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                        </xsl:element>
                </xsl:if>
        </xsl:template>
        <xsl:template name = "EntiteValideur">
                <xsl:param name = "eltPere"/>
                <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyLegalEntity">
                        <xsl:element name = "table">
                                <xsl:attribute name = "class">EnteteFournisseur</xsl:attribute>
                                <xsl:element name = "tr">
                                        <xsl:element name = "th">
                                                <xsl:attribute name = "class">EnteteFournisseur</xsl:attribute>
                                                Valideur
                                        </xsl:element>
                                </xsl:element>
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">
                                                <xsl:element name = "b">
                                                        <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyLegalEntity/cbc:RegistrationName"/>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:element>
                                <xsl:for-each select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyLegalEntity/cac:RegistrationAddress/cac:AddressLine">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        <xsl:value-of select = "cbc:Line"/>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:for-each>
				<xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:StreetName/text()">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:StreetName"/>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">
                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:PostalZone"/>
                                                &nbsp;
                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:CityName"/>
                                        </xsl:element>
                                </xsl:element>
                                <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyLegalEntity/cac:RegistrationAddress/cac:Country/cbc:IdentificationCode">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        <xsl:call-template name = "libPays">
                                                                <xsl:with-param name = "cod" select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyLegalEntity/cac:RegistrationAddress/cac:Country/cbc:IdentificationCode"/>
                                                        </xsl:call-template>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
								<xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:Contact/cbc:Name">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        <xsl:element name = "b">
                                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:Contact/cbc:Name/text()"/>
                                                        </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                                <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:Contact/cbc:Telephone">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        Téléphone :&nbsp;
                                                        <xsl:element name = "b">
                                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:Contact/cbc:Telephone/text()"/>
                                                        </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                                <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:Contact/cbc:Telefax">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        Télécopie :&nbsp;
                                                        <xsl:element name = "b">
                                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:Contact/cbc:Telefax/text()"/>
                                                        </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
								
								<xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:Contact/cbc:ElectronicMail">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        Messagerie :&nbsp;
                                                        <xsl:element name = "b">
                                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:Contact/cbc:ElectronicMail/text()"/>
                                                        </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
								<xsl:for-each select="$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:Contact/cbc:Note">
                                        <xsl:element name="tr">
                                                <xsl:element name="td">                      
                                                                <xsl:value-of select="./text()"/>
                                                        
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:for-each>
								
                        </xsl:element>
						
						<!--deb ajout SIRET Valideur-->
						<xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyIdentification/cbc:ID">
							<xsl:element name = "table">
								<xsl:attribute name = "class">EnteteFournisseur</xsl:attribute>
								<xsl:element name = "tr">
									<xsl:element name = "td">
                                        <xsl:choose>
											<xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyIdentification[cbc:ID/@schemeName='1']">
                                        		<xsl:choose>
													<xsl:when test="string-length($eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyIdentification/cbc:ID)=9">SIREN :&nbsp;</xsl:when>
													<xsl:otherwise> SIRET :&nbsp; </xsl:otherwise>
                                        		</xsl:choose>
											</xsl:when>
                                                <xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyIdentification[cbc:ID/@schemeName='2']">Structure Européenne hors France :&nbsp;</xsl:when>
                                                <xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyIdentification[cbc:ID/@schemeName='3']">Structure hors UE :&nbsp;</xsl:when>
                                                <xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyIdentification[cbc:ID/@schemeName='4']">RIDET :&nbsp;</xsl:when>
                                                <xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyIdentification[cbc:ID/@schemeName='5']">Numéro Tahiti :&nbsp;</xsl:when>
                                                <xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyIdentification[cbc:ID/@schemeName='6']">En cours dimmatriculation :&nbsp;</xsl:when>
                                                <xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyIdentification[cbc:ID/@schemeName='6']">Particulier :&nbsp;</xsl:when>
											<xsl:otherwise>
                                        		<xsl:choose>
													<xsl:when test="string-length($eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyIdentification/cbc:ID)=9">SIREN :&nbsp;</xsl:when>
													<xsl:otherwise> SIRET :&nbsp; </xsl:otherwise>
                                        		</xsl:choose>
											</xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:element name = "b">
                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:AgentParty/cac:PartyIdentification/cbc:ID/text()"/>
                                        </xsl:element>
									</xsl:element>
								</xsl:element>   
							</xsl:element>
						 </xsl:if>
						<!--final ajout SIRET Valideur-->
                </xsl:if>
				
        </xsl:template>
		
        <xsl:template name = "EntiteCommercial">
                <xsl:param name = "eltPere"/>
                <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party">
                        <xsl:element name = "table">
                                <xsl:attribute name = "class">EnteteFournisseur</xsl:attribute>
                                <xsl:element name = "tr">
                                        <xsl:element name = "th">
                                                <xsl:attribute name = "class">EnteteFournisseur</xsl:attribute>
                                                Entité&nbsp;Commerciale
                                        </xsl:element>
                                </xsl:element>
                                <xsl:for-each select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyName">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        <xsl:element name = "b">
                                                                <xsl:value-of select = "cbc:Name"/>
                                                        </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:for-each>
                                <xsl:for-each select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cac:AddressLine">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        <xsl:value-of select = "."/>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:for-each>
				<xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:StreetName/text()">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:StreetName"/>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">
                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:PostalZone"/>
                                                &nbsp;
                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:CityName"/>
                                        </xsl:element>
                                </xsl:element>
                                <!--libellé du pays -->
                                <!--AXYUS : 25/05/2016 ANNULATION report modifications concernant le libellé du pays : 
                                  QUESTION : est-ce pertinent d'avoir un IdentificationCode plutôt que son libellé, à moins que IdentificationCode contienne le libellé ? 
                                -->
                                <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cac:Country/cbc:IdentificationCode">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        <xsl:call-template name = "libPays">
                                                                <xsl:with-param name = "cod" select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cac:Country/cbc:IdentificationCode"/>
                                                        </xsl:call-template>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                        </xsl:element>
                </xsl:if>
        </xsl:template>
        
        <!--AXYUS : 25/05/2016 report : 12/04/2016 FCA -->
        <xsl:template name="InformationsContactEntiteCommercial">
                <xsl:param name = "eltPere"/>
                <xsl:if test="$eltPere/cac:AccountingSupplierParty/cac:Party/cac:Contact">
                        <xsl:element name="table">
                                <xsl:attribute name="class">EnteteFournisseur</xsl:attribute>
                                <xsl:if test="$eltPere/cac:AccountingSupplierParty/cac:Party/cac:Contact/cbc:Id">
                                        <xsl:element name="tr">
                                                <xsl:element name="td"> Code service : &nbsp;<xsl:element name="b">
                                                        <xsl:value-of
                                                                select="$eltPere/cac:AccountingSupplierParty/cac:Party/cac:Contact/cbc:Id"
                                                        />
                                                </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                                <xsl:if
                                        test="$eltPere/cac:AccountingSupplierParty/cac:Party/cac:Contact/cbc:Name">
                                        <xsl:element name="tr">
                                                <xsl:element name="td"> Nom service : &nbsp;<xsl:element name="b">
                                                        <xsl:value-of
                                                                select="$eltPere/cac:AccountingSupplierParty/cac:Party/cac:Contact/cbc:Name"
                                                        />
                                                </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                        </xsl:element>
                </xsl:if>
        </xsl:template>
        
        <xsl:template name = "InformationsFournisseur">
                <xsl:param name = "eltPere"/>
                <xsl:element name = "table">
                        <xsl:attribute name = "class">EnteteFournisseur</xsl:attribute>
                        <xsl:element name = "tr">
                                <xsl:element name = "td">
                                        <xsl:choose>
						<xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyIdentification[cbc:ID/@schemeName='1']">
                                        		<xsl:choose>
								<xsl:when test="string-length($eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyIdentification/cbc:ID)=9">SIREN :&nbsp;</xsl:when>
								<xsl:otherwise> SIRET :&nbsp; </xsl:otherwise>
                                        		</xsl:choose>
						</xsl:when>
                                                <xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyIdentification[cbc:ID/@schemeName='2']">Structure Européenne hors France :&nbsp;</xsl:when>
                                                <xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyIdentification[cbc:ID/@schemeName='3']">Structure hors UE :&nbsp;</xsl:when>
                                                <xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyIdentification[cbc:ID/@schemeName='4']">RIDET :&nbsp;</xsl:when>
                                                <xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyIdentification[cbc:ID/@schemeName='5']">Numéro Tahiti :&nbsp;</xsl:when>
                                                <xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyIdentification[cbc:ID/@schemeName='6']">En cours dimmatriculation :&nbsp;</xsl:when>
                                                <xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyIdentification[cbc:ID/@schemeName='6']">Particulier :&nbsp;</xsl:when>
						<xsl:otherwise>
                                        		<xsl:choose>
								<xsl:when test="string-length($eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyIdentification/cbc:ID)=9">SIREN :&nbsp;</xsl:when>
								<xsl:otherwise> SIRET :&nbsp; </xsl:otherwise>
                                        		</xsl:choose>
						</xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:element name = "b">
                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyIdentification/cbc:ID/text()"/>
                                        </xsl:element>
                                </xsl:element>
                        </xsl:element>
						
			<xsl:if test="$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cbc:CompanyID">
	                        <xsl:element name = "tr">
	                                <xsl:element name = "td">
	                                        Numéro de TVA intra-communautaire :&nbsp;
	                                        <xsl:element name = "b">
	                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cbc:CompanyID"/>
	                                        </xsl:element>
	                                </xsl:element>
	                        </xsl:element>
			</xsl:if>
			
			<xsl:if test="$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:TaxTypeCode/text()">
	                        <xsl:element name = "tr">
	                                <xsl:element name = "td">
	                                        Régime de TVA :&nbsp;
	                                        <xsl:element name = "b">
	                                                <xsl:choose>
	                                                        <xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:TaxTypeCode/text() = 'TVA DEBIT'">TVA sur les débits</xsl:when>
	                                                        <xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:TaxTypeCode/text() = 'TVA ENCAISSEMENT'">TVA sur les encaissements</xsl:when>
	                                                        <xsl:when test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:TaxTypeCode/text() = 'EXONERATION'"> TVA éxonérée </xsl:when>
	                                                        <xsl:otherwise>
	                                                                Inconnu (code=
	                                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:TaxTypeCode/text()"/>
	                                                                )
	                                                        </xsl:otherwise>
	                                                </xsl:choose>
	                                        </xsl:element>
	                                </xsl:element>
	                        </xsl:element>
			</xsl:if>
                        <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:CompanyID">
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">
                                                RCS :&nbsp;
                                                <xsl:element name = "b">
                                                        <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:CompanyID/text()"/>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:element>
                        </xsl:if>
                </xsl:element>
        </xsl:template>
        <xsl:template name = "ContactFournisseur">
                <xsl:param name = "eltPere"/>
                <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:AccountingContact">
                        <xsl:element name = "table">
                                <xsl:attribute name = "class">EnteteFournisseur</xsl:attribute>
                                <xsl:element name = "tr">
                                        <xsl:element name = "th">
                                                <xsl:attribute name = "class">EnteteFournisseur</xsl:attribute>
                                                Contact
                                        </xsl:element>
                                </xsl:element>
                                <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:AccountingContact/cbc:Name">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        <xsl:element name = "b">
                                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:AccountingContact/cbc:Name/text()"/>
                                                        </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                                <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:AccountingContact/cbc:Telephone">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        Téléphone :&nbsp;
                                                        <xsl:element name = "b">
                                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:AccountingContact/cbc:Telephone/text()"/>
                                                        </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                                <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:AccountingContact/cbc:Telefax">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        Télécopie :&nbsp;
                                                        <xsl:element name = "b">
                                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:AccountingContact/cbc:Telefax/text()"/>
                                                        </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                                <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:AccountingContact/cbc:ElectronicMail">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        Messagerie :&nbsp;
                                                        <xsl:element name = "b">
                                                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:AccountingContact/cbc:ElectronicMail/text()"/>
                                                        </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                                
                                <xsl:for-each select="$eltPere/cac:AccountingSupplierParty/cac:Party/cac:Contact/cbc:Note">
                                        <xsl:element name="tr">
                                                <xsl:element name="td">
                                                        <xsl:value-of select="./text()" />
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:for-each>
                        </xsl:element>
                </xsl:if>
        </xsl:template>

        
        <xsl:template name = "EnteteClient">
                <xsl:param name = "eltPere"/>
                <xsl:element name = "table">
                        <xsl:attribute name = "class">EnteteClient</xsl:attribute>
                        <xsl:element name = "tr">
                                <xsl:element name = "th">
                                        <xsl:attribute name = "class">EnteteClient</xsl:attribute>
                                        Client
                                </xsl:element>
                        </xsl:element>
                        <xsl:element name = "tr">
                                <xsl:element name = "td">
                                        <xsl:element name = "b">
                                                <xsl:for-each select = "$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PartyName/cbc:Name">
                                                        <xsl:value-of select = "./text()"/>
                                                        <xsl:element name = "br"/>
                                                </xsl:for-each>
                                        </xsl:element>
                                </xsl:element>
                        </xsl:element>
                        <xsl:for-each select = "$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cac:AddressLine/cbc:Line">
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">
                                                <xsl:value-of select = "."/>
                                        </xsl:element>
                                </xsl:element>
                        </xsl:for-each>
                        
                        <xsl:element name="tr">
                                <xsl:element name="td">
                                        <xsl:value-of
                                                select="$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:StreetName"
                                        />
                                </xsl:element>
                        </xsl:element>
                        
                        <xsl:element name = "tr">
                                <xsl:element name = "td">
                                        <xsl:value-of select = "$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:PostalZone"/>
                                        &nbsp;
                                        <xsl:value-of select = "$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:CityName"/>
                                </xsl:element>
                        </xsl:element>

                        <xsl:if test = "$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cac:Country/cbc:IdentificationCode">
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">
                                                <xsl:call-template name = "libPays">
                                                        <xsl:with-param name = "cod" select = "$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cac:Country/cbc:IdentificationCode"/>
                                                </xsl:call-template>
                                        </xsl:element>
                                </xsl:element>
                        </xsl:if>
                </xsl:element>
                <xsl:element name = "table">
                        <xsl:attribute name = "class">EnteteClient</xsl:attribute>

                        
                        <xsl:element name="tr">
                            <xsl:element name="td"> 
                                <xsl:element name="b">                         
                                    <xsl:choose>
										<xsl:when test = "$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PartyIdentification[cbc:ID/@schemeName='1']">
                                        	<xsl:choose>
												<xsl:when test="string-length($eltPere/cac:AccountingCustomerParty/cac:Party/cac:PartyIdentification/cbc:ID)=9">SIREN :&nbsp;</xsl:when>
												<xsl:otherwise> SIRET :&nbsp; </xsl:otherwise>
                                        	</xsl:choose>
										</xsl:when>
                                             <xsl:when test = "$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PartyIdentification[cbc:ID/@schemeName='2']">Structure Européenne hors France :&nbsp;</xsl:when>
                                             <xsl:when test = "$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PartyIdentification[cbc:ID/@schemeName='3']">Structure hors UE :&nbsp;</xsl:when>
                                             <xsl:when test = "$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PartyIdentification[cbc:ID/@schemeName='4']">RIDET :&nbsp;</xsl:when>
                                             <xsl:when test = "$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PartyIdentification[cbc:ID/@schemeName='5']">Numéro Tahiti :&nbsp;</xsl:when>
                                             <xsl:when test = "$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PartyIdentification[cbc:ID/@schemeName='6']">En cours dimmatriculation :&nbsp;</xsl:when>
                                             <xsl:when test = "$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PartyIdentification[cbc:ID/@schemeName='6']">Particulier :&nbsp;</xsl:when>
										<xsl:otherwise>
											<xsl:choose>
												<xsl:when test="string-length($eltPere/cac:AccountingCustomerParty/cac:Party/cac:PartyIdentification/cbc:ID)=9">SIREN :&nbsp;</xsl:when>
												<xsl:otherwise> SIRET :&nbsp; </xsl:otherwise>
                                        	</xsl:choose>
										</xsl:otherwise>
                                    </xsl:choose>
                                </xsl:element>
                                       	<xsl:element name = "b">
                                         	<xsl:value-of select = "$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PartyIdentification/cbc:ID/text()"/>
                                        </xsl:element>
                            </xsl:element>
                        </xsl:element> 

                        <xsl:if test="$eltPere/cac:OrderReference/cbc:ID">
                                <xsl:element name="tr">
                                        <xsl:element name="td"> Numéro d'engagement : <xsl:element name="b">
                                                <xsl:value-of
                                                        select="$eltPere/cac:OrderReference/cbc:ID"
                                                />
                                        </xsl:element>
                                                <xsl:if
                                                        test="$eltPere/cac:OrderReference/cbc:IssueDate/text()"
                                                        > &nbsp;du&nbsp; <xsl:call-template name="slash-date">
                                                                <xsl:with-param name="datebrute"
                                                                        select="$eltPere/cac:OrderReference/cbc:IssueDate/text()"
                                                                />
                                                        </xsl:call-template>
                                                </xsl:if>
                                        </xsl:element>
                                </xsl:element>
                        </xsl:if>
                        <xsl:if test="$eltPere/cac:ContractDocumentReference[cbc:DocumentTypeCode='Marché Public']/cbc:ID">
                                <xsl:element name="tr">
                                        <xsl:element name="td">Marché : <xsl:element name="b">
                                                <xsl:value-of
                                                        select="$eltPere/cac:ContractDocumentReference[cbc:DocumentTypeCode='Marché Public']/cbc:ID"
                                                />
                                        </xsl:element>
                                                <xsl:if
                                                        test="$eltPere/cac:ContractDocumentReference[cbc:DocumentTypeCode='Marché Public']/cbc:IssueDate/text()"
                                                        > &nbsp;du&nbsp; <xsl:call-template name="slash-date">
                                                                <xsl:with-param name="datebrute"
                                                                        select="$eltPere/cac:ContractDocumentReference[cbc:DocumentTypeCode='Marché Public']/cbc:IssueDate/text()"
                                                                />
                                                        </xsl:call-template>
                                                </xsl:if>
                                        </xsl:element>
                                </xsl:element>
                        </xsl:if>
						<xsl:if test="$eltPere/cac:ContractDocumentReference[cbc:DocumentTypeCode='Contrat']/cbc:ID">
                                <xsl:element name="tr">
                                        <xsl:element name="td">Contrat : <xsl:element name="b">
                                                <xsl:value-of
                                                        select="$eltPere/cac:ContractDocumentReference[cbc:DocumentTypeCode='Contrat']/cbc:ID"
                                                />
                                        </xsl:element>
                                                <xsl:if
                                                        test="$eltPere/cac:ContractDocumentReference[cbc:DocumentTypeCode='Contrat']/cbc:IssueDate/text()"
                                                        > &nbsp;du&nbsp; <xsl:call-template name="slash-date">
                                                                <xsl:with-param name="datebrute"
                                                                        select="$eltPere/cac:ContractDocumentReference[cbc:DocumentTypeCode='Contrat']/cbc:IssueDate/text()"
                                                                />
                                                        </xsl:call-template>
                                                </xsl:if>
                                        </xsl:element>
                                </xsl:element>
                        </xsl:if>
                        <xsl:if test="$eltPere/cac:ContractDocumentReference[cbc:DocumentTypeCode='Bon de commande']/cbc:ID and not($eltPere/cac:OrderReference/cbc:ID)">
                                <xsl:element name="tr">
                                        <xsl:element name="td">Numéro d'engagement : <xsl:element name="b">
                                                <xsl:value-of
                                                        select="$eltPere/cac:ContractDocumentReference[cbc:DocumentTypeCode='Bon de commande']/cbc:ID"
                                                />
                                        </xsl:element>
                                                <xsl:if
                                                        test="$eltPere/cac:ContractDocumentReference[cbc:DocumentTypeCode='Bon de commande']/cbc:IssueDate/text()"
                                                        > &nbsp;du&nbsp; <xsl:call-template name="slash-date">
                                                                <xsl:with-param name="datebrute"
                                                                        select="$eltPere/cac:ContractDocumentReference[cbc:DocumentTypeCode='Bon de commande']/cbc:IssueDate/text()"
                                                                />
                                                        </xsl:call-template>
                                                </xsl:if>
                                        </xsl:element>
                                </xsl:element>
                        </xsl:if>
                        <xsl:if test="$eltPere/cac:ContractDocumentReference[cbc:DocumentTypeCode='Engagement']/cbc:ID and not($eltPere/cac:OrderReference/cbc:ID)">
                                <xsl:element name="tr">
                                        <xsl:element name="td">Numéro d'Engagement : <xsl:element name="b">
                                                <xsl:value-of
                                                        select="$eltPere/cac:ContractDocumentReference[cbc:DocumentTypeCode='Engagement']/cbc:ID"
                                                />
                                        </xsl:element>
                                                <xsl:if
                                                        test="$eltPere/cac:ContractDocumentReference[cbc:DocumentTypeCode='Engagement']/cbc:IssueDate/text()"
                                                        > &nbsp;du&nbsp; <xsl:call-template name="slash-date">
                                                                <xsl:with-param name="datebrute"
                                                                        select="$eltPere/cac:ContractDocumentReference[cbc:DocumentTypeCode='Engagement']/cbc:IssueDate/text()"
                                                                />
                                                        </xsl:call-template>
                                                </xsl:if>
                                        </xsl:element>
                                </xsl:element>
                        </xsl:if>

                        <xsl:if test = "$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cbc:CompanyID">
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">
                                                Numéro de TVA Intra-communautaire :&nbsp;
                                                <xsl:element name = "b">
                                                        <xsl:value-of select = "$eltPere/cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cbc:CompanyID/text()"/>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:element>
                        </xsl:if>
                </xsl:element>
        </xsl:template>

        <xsl:template name = "EnteteServiceRecepteur">
                <xsl:param name = "eltPere"/>
				<xsl:if test = "$eltPere/cac:AccountingCustomerParty/cac:AccountingContact/cbc:ID">
					<xsl:element name="table">
					<xsl:attribute name="class">EnteteServiceRecepteur</xsl:attribute>
					<xsl:element name="tr">
                        <xsl:element name="th">
                                <xsl:attribute name="class">EnteteServiceRecepteur</xsl:attribute> Service
                                Récepteur </xsl:element>
						</xsl:element>
					<xsl:element name="tr">
                        <xsl:element name="td">
                                <xsl:element name="b">
                                        <xsl:for-each
                                                select="$eltPere/cac:AccountingCustomerParty/cac:AccountingContact/cbc:ID">
                                                <xsl:value-of select="./text()"/>
                                                <xsl:element name="br"/>
                                        </xsl:for-each>
                                </xsl:element>
                        </xsl:element>
					</xsl:element>
					<xsl:element name="tr">
                        <xsl:element name="td">
                                <xsl:value-of
                                        select="$eltPere/cac:AccountingCustomerParty/cac:AccountingContact/cbc:Name"
                                />
                        </xsl:element>
					</xsl:element>
					<xsl:for-each select="$eltPere/cac:AccountingCustomerParty/cac:Party/cac:Contact/cbc:Note">					
						<xsl:element name="tr">
							<xsl:element name="td">
								<xsl:value-of select="./text()"/>
							</xsl:element>
						</xsl:element>
					</xsl:for-each>
				</xsl:element>					
			</xsl:if>
        </xsl:template>

        <xsl:template name = "EnteteEncaisseur">
                <xsl:param name = "eltPere"/>
                <xsl:if test = "$eltPere/cac:PayeeParty/cac:PartyLegalEntity">
                        <xsl:element name = "table">
                                <xsl:attribute name = "class">EnteteServiceRecepteur</xsl:attribute>
                                <xsl:element name = "tr">
                                        <xsl:element name = "th">
                                                <xsl:attribute name = "class">EnteteServiceRecepteur</xsl:attribute>
                                                Encaisseur
                                        </xsl:element>
                                </xsl:element>
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">
                                                <xsl:element name = "b">
                                                        <xsl:value-of select = "$eltPere/cac:PayeeParty/cac:PartyName/cbc:Name"/>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:element>
                                <xsl:for-each select = "$eltPere/cac:PayeeParty/cac:PartyLegalEntity/cac:RegistrationAddress/cac:AddressLine">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        <xsl:value-of select = "cbc:Line"/>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:for-each>
				<xsl:if test = "$eltPere/cac:PayeeParty/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:StreetName/text()">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                <xsl:value-of select = "$eltPere/cac:PayeeParty/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:StreetName"/>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">
                                                <xsl:value-of select = "$eltPere/cac:PayeeParty/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:PostalZone"/>
                                                &nbsp;
                                                <xsl:value-of select = "$eltPere/cac:PayeeParty/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:CityName"/>
                                        </xsl:element>
                                </xsl:element>
                                <xsl:if test = "$eltPere/cac:PayeeParty/cac:PartyLegalEntity/cac:RegistrationAddress/cac:Country/cbc:IdentificationCode">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        <xsl:call-template name = "libPays">
                                                                <xsl:with-param name = "cod" select = "$eltPere/cac:PayeeParty/cac:PartyLegalEntity/cac:RegistrationAddress/cac:Country/cbc:IdentificationCode"/>
                                                        </xsl:call-template>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>

                                <xsl:if test = "$eltPere/cac:PayeeParty/cac:Contact/cbc:Name">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        <xsl:element name = "b">
                                                                <xsl:value-of select = "$eltPere/cac:PayeeParty/cac:Contact/cbc:Name/text()"/>
                                                        </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                                <xsl:if test = "$eltPere/cac:PayeeParty/cac:Contact/cbc:Telephone">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        Téléphone :&nbsp;
                                                        <xsl:element name = "b">
                                                                <xsl:value-of select = "$eltPere/cac:PayeeParty/cac:Contact/cbc:Telephone/text()"/>
                                                        </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                                <xsl:if test = "$eltPere/cac:PayeeParty/cac:Contact/cbc:Telefax">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        Télécopie :&nbsp;
                                                        <xsl:element name = "b">
                                                                <xsl:value-of select = "$eltPere/cac:PayeeParty/cac:Contact/cbc:Telefax/text()"/>
                                                        </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
                                <xsl:if test = "$eltPere/cac:PayeeParty/cac:Contact/cbc:ElectronicMail">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        Messagerie :&nbsp;
                                                        <xsl:element name = "b">
                                                                <xsl:value-of select = "$eltPere/cac:PayeeParty/cac:Contact/cbc:ElectronicMail/text()"/>
                                                        </xsl:element>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:if>
								
								<xsl:for-each select="$eltPere/cac:PayeeParty/cac:Contact/cbc:Note">
                                        <xsl:element name="tr">
                                                <xsl:element name="td">
                                                        <xsl:value-of select="./text()" />
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:for-each>
								
						</xsl:element>
<!--deb ajout SIRET Encaisseur-->
						<xsl:if test = "$eltPere/cac:PayeeParty/cac:PartyIdentification/cbc:ID">
							<xsl:element name = "table">
								<xsl:attribute name = "class">EnteteServiceRecepteur</xsl:attribute>
								<xsl:element name = "tr">
									<xsl:element name = "td">
										<xsl:element name = "b">
											<xsl:choose>
												<xsl:when test = "$eltPere/cac:PayeeParty/cac:PartyIdentification[cbc:ID/@schemeName='1']">
													<xsl:choose>
														<xsl:when test="string-length($eltPere/cac:PayeeParty/cac:PartyIdentification/cbc:ID)=9">SIREN :&nbsp;</xsl:when>
														<xsl:otherwise> SIRET :&nbsp; </xsl:otherwise>
													</xsl:choose>
												</xsl:when>
													<xsl:when test = "$eltPere/cac:PayeeParty/cac:PartyIdentification[cbc:ID/@schemeName='2']">Structure Européenne hors France :&nbsp;</xsl:when>
													<xsl:when test = "$eltPere/cac:PayeeParty/cac:PartyIdentification[cbc:ID/@schemeName='3']">Structure hors UE :&nbsp;</xsl:when>
													<xsl:when test = "$eltPere/cac:PayeeParty/cac:PartyIdentification[cbc:ID/@schemeName='4']">RIDET :&nbsp;</xsl:when>
													<xsl:when test = "$eltPere/cac:PayeeParty/cac:PartyIdentification[cbc:ID/@schemeName='5']">Numéro Tahiti :&nbsp;</xsl:when>
													<xsl:when test = "$eltPere/cac:PayeeParty/cac:PartyIdentification[cbc:ID/@schemeName='6']">En cours dimmatriculation :&nbsp;</xsl:when>
													<xsl:when test = "$eltPere/cac:PayeeParty/cac:PartyIdentification[cbc:ID/@schemeName='6']">Particulier :&nbsp;</xsl:when>
												<xsl:otherwise>
													<xsl:choose>
														<xsl:when test="string-length($eltPere/cac:PayeeParty/cac:PartyIdentification/cbc:ID)=9">SIREN :&nbsp;</xsl:when>
														<xsl:otherwise> SIRET :&nbsp; </xsl:otherwise>
													</xsl:choose>
												</xsl:otherwise>
											</xsl:choose>
											<xsl:element name = "b">
                                                <xsl:value-of select = "$eltPere/cac:PayeeParty/cac:PartyIdentification/cbc:ID/text()"/>
											</xsl:element>
										</xsl:element>
									</xsl:element>
								</xsl:element>   
							</xsl:element>
						</xsl:if>
<!--final ajout SIRET encaisseur-->

                    
                </xsl:if>
        </xsl:template>
        
		<xsl:template name = "EnteteSite">
                <xsl:param name = "site"/>
                <xsl:param name = "nbSite"/>

                <xsl:if test = "$nbSite>1">
                        <xsl:element name = "div">
                                <xsl:attribute name = "style">page-break-before:always</xsl:attribute>
                        </xsl:element>
                </xsl:if>
                <xsl:element name = "br"/>
                <xsl:element name = "table">
                        <xsl:attribute name = "class">EnteteSite</xsl:attribute>
                        <xsl:element name = "tr">
                                <xsl:element name = "td">
                                        <b>
                                                Site de livraison :&nbsp;
                                                <xsl:for-each select = "$site/cac:DeliveryLocation/cbc:Description">
                                                        <xsl:value-of select = "./text()"/>
                                                        &nbsp;
                                                </xsl:for-each>
                                        </b>
                                        &nbsp;-&nbsp;
                                        <xsl:for-each select = "$site/cac:DeliveryLocation/cac:Address/cac:AddressLine">
                                                <xsl:value-of select = "cbc:Line"/>
                                                &nbsp;
                                        </xsl:for-each>
                                        <xsl:value-of select = "$site/cac:DeliveryLocation/cac:Address/cbc:PostalZone"/>
                                        &nbsp;
                                        <xsl:value-of select = "$site/cac:DeliveryLocation/cac:Address/cbc:CityName"/>
                                        &nbsp;
                                        <xsl:if test = "$site/cac:DeliveryLocation/cac:Address/cac:Country/cbc:IdentificationCode">
                                                <xsl:call-template name = "libPays">
                                                        <xsl:with-param name = "cod" select = "$site/cac:DeliveryLocation/cac:Address/cac:Country/cbc:IdentificationCode"/>
                                                </xsl:call-template>
                                        </xsl:if>
                                </xsl:element>
                        </xsl:element>
                </xsl:element>
        </xsl:template>
        <xsl:template name = "EnteteSiteSansSite">
                <xsl:element name = "div">
                        <xsl:attribute name = "style">page-break-before:always</xsl:attribute>
                </xsl:element>
                <xsl:element name = "br"/>
                <xsl:element name = "table">
                        <xsl:attribute name = "class">EnteteSite</xsl:attribute>
                        <xsl:element name = "tr">
                                <xsl:element name = "td">
                                        <b>Articles rattachés au compte client</b>
                                </xsl:element>
                        </xsl:element>
                </xsl:element>
        </xsl:template>
        <xsl:template name = "LigneFacture">
                <xsl:param name = "lignes"/>
                <xsl:element name = "table">
                        <xsl:attribute name = "width">100%</xsl:attribute>
                        <xsl:attribute name = "style">
                                bordered collapsed; page-break-inside:
                                avoid;
                        </xsl:attribute>
                        <xsl:attribute name = "cellpadding">0</xsl:attribute>
                        <xsl:attribute name = "cellspacing">2</xsl:attribute>
                        <xsl:element name = "colgroup">
                                <xsl:element name = "col">
                                        <xsl:attribute name = "width">5%</xsl:attribute>
                                </xsl:element>
                                <xsl:element name = "col">
                                        <xsl:attribute name = "width">45%</xsl:attribute>
                                </xsl:element>
                                <xsl:element name = "col">
                                        <xsl:attribute name = "width">10%</xsl:attribute>
                                </xsl:element>
                                <xsl:element name = "col">
                                        <xsl:attribute name = "width">11%</xsl:attribute>
                                </xsl:element>
                                <xsl:element name = "col">
                                        <xsl:attribute name = "width">10%</xsl:attribute>
                                </xsl:element>
                                <xsl:element name = "col">
                                        <xsl:attribute name = "width">9%</xsl:attribute>
                                </xsl:element>
                                <xsl:element name = "col">
                                        <xsl:attribute name = "width">10%</xsl:attribute>
                                </xsl:element>
                        </xsl:element>
                        <xsl:element name = "thead">
                                <xsl:element name = "tr">
                                        <xsl:element name = "th">
                                                <xsl:attribute name = "class">bordered</xsl:attribute>
                                                <xsl:attribute name = "style">font-size: 8px;</xsl:attribute>
                                                TVA
                                        </xsl:element>
                                        <xsl:element name = "th">
                                                <xsl:attribute name = "class">bordered</xsl:attribute>
                                                Dénomination de
                                                l'article
                                        </xsl:element>
                                        <xsl:element name = "th">
                                                <xsl:attribute name = "class">bordered</xsl:attribute>
                                                Quantité
                                                facturée
                                        </xsl:element>
                                        <xsl:element name = "th">
                                                <xsl:attribute name = "class">bordered</xsl:attribute>
                                                Prix
                                                unitaire
                                        </xsl:element>
                                        <xsl:element name = "th">
                                                <xsl:attribute name = "class">bordered</xsl:attribute>

                                                Quantité
                                                de
												livraison
                                        </xsl:element>
                                        <xsl:element name = "th">
                                                <xsl:attribute name = "class">bordered</xsl:attribute>
                                                Total
                                                remise/charge
                                        </xsl:element>
                                        <xsl:element name = "th">
                                                <xsl:attribute name = "class">bordered</xsl:attribute>
                                                Total HT
                                        </xsl:element>
                                </xsl:element>
                        </xsl:element>
                        <xsl:element name = "tbody">
                                <xsl:for-each select = "$lignes">
                                        <xsl:element name = "tr">
                                                <xsl:element name = "td">
                                                        <xsl:attribute name = "class">top</xsl:attribute>
                                                        <xsl:attribute name = "style">font-size: 8px;</xsl:attribute>
                                                        <xsl:choose>
                                                                <xsl:when test = "cac:Item/cac:ClassifiedTaxCategory/cbc:Percent">
                                                                        <xsl:call-template name = "number">
                                                                                <xsl:with-param name = "num" select = "cac:Item/cac:ClassifiedTaxCategory/cbc:Percent"/>
                                                                        </xsl:call-template>
                                                                </xsl:when>
                                                                <xsl:otherwise>&nbsp;</xsl:otherwise>
                                                        </xsl:choose>
                                                </xsl:element>
                                                <xsl:element name = "td">
                                                        <xsl:attribute name = "class">top normal</xsl:attribute>
                                                        <table
                                                                cellpadding = "0"
                                                                cellspacing = "0"
                                                                border = "0">
                                                                <xsl:if test = "cac:Item/cbc:Name">
                                                                        <tr>
                                                                                <td>
                                                                                        <xsl:if test = "./cbc:ID">
                                                                                                <xsl:value-of select = "./cbc:ID"/>
                                                                                                -
                                                                                        </xsl:if>
                                                                                        <xsl:value-of select = "cac:Item/cbc:Name"/>
                                                                                </td>
                                                                        </tr>
                                                                </xsl:if>

                                                                <!--AXYUS : 25/05/2016 report : 12/04/2016 FAC : Ajout type et sous-type-->
                                                                <xsl:if test="cac:Item/cac:AdditionalItemProperty">
                                                                        <tr>
                                                                                <td>
                                                                                        <xsl:if
                                                                                                test="./cac:Item/cac:AdditionalItemProperty/cbc:Name">
                                                                                                <xsl:value-of
                                                                                                        select="./cac:Item/cac:AdditionalItemProperty/cbc:Name"
                                                                                                /> - </xsl:if>
                                                                                        <xsl:if
                                                                                                test="./cac:Item/cac:AdditionalItemProperty/cbc:Value">
                                                                                                <xsl:value-of
                                                                                                        select="./cac:Item/cac:AdditionalItemProperty/cbc:Value"
                                                                                                />
                                                                                        </xsl:if>
                                                                                </td>
                                                                        </tr>
                                                                </xsl:if>
																<!-- ne plus afficher
                                                                <xsl:if test="cac:Delivery">
                                                                        <tr>
                                                                                <td>
                                                                                        <xsl:value-of select="./cac:Delivery/cbc:ID"/>
                                                                                </td>
                                                                        </tr>
                                                                </xsl:if> -->
                                                                <xsl:if test = "cac:Item/cbc:Description">
                                                                        <tr>
										<td style = "font-size: 9px;">
                                                                                        <xsl:for-each select = "cac:Item/cbc:Description">
                                                                                                <xsl:value-of select = "./text()"/>
                                                                                                &nbsp;
                                                                                        </xsl:for-each>
                                                                                </td>
                                                                        </tr>
                                                                </xsl:if>
                                                                
                                                                <xsl:if test="cac:Item/cac:StandardItemIdentification">
                                                                        <tr>
                                                                                <td style="font-size: 7px;">Référence produit :&nbsp;
                                                                                        <xsl:value-of
                                                                                                select="cac:Item/cac:StandardItemIdentification/cbc:ID"
                                                                                        />
                                                                                </td>
                                                                        </tr>
                                                                </xsl:if>
                                                                
                                                                        <xsl:if test = "cac:Delivery/cbc:ActualDeliveryDate">
                                                                                <tr>
                                                                                        <td>
												Date de livraison :
												<xsl:call-template name = "slash-date">
                                                                                                     <xsl:with-param name = "datebrute" select = "cac:Delivery/cbc:ActualDeliveryDate/text()"/>
												</xsl:call-template>
												<xsl:if test = "cac:Delivery/cbc:TrackingID">
													- N° bon de livraison : 
												    <xsl:value-of select = "cac:Delivery/cbc:TrackingID/text()"/>
												</xsl:if>
                                                                                        </td>																						
                                                                                </tr>
                                                                        </xsl:if>
                                                                <xsl:for-each select="cbc:Note">
																	<tr>
                                                                         <xsl:call-template name="tokenizeNotes">
                                                                                <xsl:with-param name="list" select="./text()"/>
                                                                                <xsl:with-param name="delimiter" select="'§'"/>
                                                                        </xsl:call-template>
																	</tr>	
                                                                </xsl:for-each>
                                                        </table>
                                                </xsl:element>
                                                <xsl:element name = "td">
                                                        <xsl:attribute name = "class">top right</xsl:attribute>
                                                        <xsl:choose>
                                                                <xsl:when test = "cbc:InvoicedQuantity">
                                                                        <xsl:call-template name = "number">
                                                                                <xsl:with-param name = "num" select = "cbc:InvoicedQuantity"/>
                                                                        </xsl:call-template>
																		<xsl:if test = "cbc:InvoicedQuantity/@unitCode">
																		(<xsl:value-of select = "cbc:InvoicedQuantity/@unitCode"/>)
																		</xsl:if>
                                                                </xsl:when>
                                                                <xsl:when test = "cbc:CreditedQuantity">
                                                                        <xsl:call-template name = "number">
                                                                                <xsl:with-param name = "num" select = "cbc:InvoicedQuantity"/>
                                                                        </xsl:call-template>
                                                                </xsl:when>
                                                                <xsl:otherwise>&nbsp;</xsl:otherwise>
                                                        </xsl:choose>
                                                </xsl:element>
                                                <xsl:element name = "td">
                                                        <xsl:attribute name = "class">top right</xsl:attribute>
                                                        <xsl:choose>
                                                                <xsl:when test = "cac:Price/cbc:PriceAmount">
                                                                        <xsl:call-template name = "number">
                                                                                <xsl:with-param name = "num" select = "cac:Price/cbc:PriceAmount"/>
                                                                        </xsl:call-template>
                                                                </xsl:when>
                                                                <xsl:otherwise>&nbsp;</xsl:otherwise>
                                                        </xsl:choose>
                                                </xsl:element>
                                                <xsl:element name = "td">
                                                        <xsl:attribute name = "class">top right</xsl:attribute>
                                                        <xsl:choose>
                                                                <xsl:when test = "cac:Price/cbc:BaseQuantity">
                                                                        <xsl:call-template name = "number">
                                                                                <xsl:with-param name = "num" select = "cac:Price/cbc:BaseQuantity"/>
                                                                        </xsl:call-template>
																		<xsl:if test = "cac:Price/cbc:BaseQuantity/@unitCode">
																		(<xsl:value-of select = "cac:Price/cbc:BaseQuantity/@unitCode"/>)
																		</xsl:if>
                                                                </xsl:when>
                                                                <xsl:otherwise>&nbsp;</xsl:otherwise>
                                                        </xsl:choose>
                                                </xsl:element>
                                                <xsl:element name = "td">
                                                        <xsl:attribute name = "class">top right</xsl:attribute>

                                                        <xsl:choose>
                                                                <xsl:when test = "cac:AllowanceCharge/cbc:Amount">
                                                                        <xsl:call-template name = "number">
                                                                                <xsl:with-param name = "num" select = "format-number(sum(cac:AllowanceCharge[cbc:ChargeIndicator='true']/cbc:Amount/text())-sum(cac:AllowanceCharge[cbc:ChargeIndicator='false']/cbc:Amount/text()),'######0.0000;-#######.0000')"/>
                                                                        </xsl:call-template>
                                                                </xsl:when>
                                                                <xsl:otherwise>&nbsp;</xsl:otherwise>
                                                        </xsl:choose>
                                                </xsl:element>
                                                <xsl:element name = "td">
                                                        <xsl:attribute name = "class">top right</xsl:attribute>
                                                        <xsl:choose>
                                                                <xsl:when test = "cbc:LineExtensionAmount">
                                                                        <xsl:call-template name = "number">
                                                                                <xsl:with-param name = "num" select = "cbc:LineExtensionAmount"/>
                                                                        </xsl:call-template>
                                                                </xsl:when>
                                                                <xsl:otherwise>&nbsp;</xsl:otherwise>
                                                        </xsl:choose>
                                                </xsl:element>
                                        </xsl:element>
                                </xsl:for-each>

                                <xsl:element name = "tr">
                                        <xsl:element name = "td">
                                                <xsl:attribute name = "colspan">6</xsl:attribute>
                                                &nbsp;
                                        </xsl:element>
                                </xsl:element>
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">
                                                <xsl:attribute name = "colspan">6</xsl:attribute>
                                                <xsl:attribute name = "style">font-size: 12px</xsl:attribute>
                                                <b>Totaux du site de livraison, pour information :</b>
                                        </xsl:element>
                                </xsl:element>
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">
                                                <xsl:attribute name = "colspan">6</xsl:attribute>
                                                &nbsp;
                                        </xsl:element>
                                </xsl:element>
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">&nbsp;</xsl:element>
                                        <xsl:element name = "td">
                                                <xsl:attribute name = "class">top</xsl:attribute>
                                                <xsl:attribute name = "class">gras</xsl:attribute>
                                                <xsl:attribute name = "colspan">5</xsl:attribute>
                                                Brut HT
                                        </xsl:element>
                                        <xsl:element name = "td">
                                                <xsl:attribute name = "class">top</xsl:attribute>
                                                <xsl:attribute name = "class">right</xsl:attribute>
                                                <xsl:call-template name = "number">
                                                        <xsl:with-param name = "num" select = "format-number(sum($lignes[not(cac:Item/cac:AdditionalItemProperty/cbc:Name/text() = 'TYPE_LIGNE' and (cac:Item/cac:AdditionalItemProperty/cbc:Value/text() = 'REGROUPEMENT' or cac:Item/cac:AdditionalItemProperty/cbc:Value/text() = 'INFORMATION'))]/cbc:LineExtensionAmount)-sum($lignes[not(cac:Item/cac:AdditionalItemProperty/cbc:Name/text() = 'TYPE_LIGNE' and (cac:Item/cac:AdditionalItemProperty/cbc:Value/text() = 'REGROUPEMENT' or cac:Item/cac:AdditionalItemProperty/cbc:Value/text() = 'INFORMATION'))]/cac:AllowanceCharge[cbc:ChargeIndicator='true']/cbc:Amount)+sum($lignes[not(cac:Item/cac:AdditionalItemProperty/cbc:Name/text() = 'TYPE_LIGNE' and (cac:Item/cac:AdditionalItemProperty/cbc:Value/text() = 'REGROUPEMENT' or cac:Item/cac:AdditionalItemProperty/cbc:Value/text() = 'INFORMATION'))]/cac:AllowanceCharge[cbc:ChargeIndicator='false']/cbc:Amount),'######0.0000;-#######.0000')"/>
                                                </xsl:call-template>
                                        </xsl:element>
                                </xsl:element>
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">&nbsp;</xsl:element>
                                        <xsl:element name = "td">
                                                <xsl:attribute name = "class">top</xsl:attribute>
                                                <xsl:attribute name = "class">gras</xsl:attribute>
                                                <xsl:attribute name = "colspan">5</xsl:attribute>
                                                Remises/charges à la ligne
                                        </xsl:element>
                                        <xsl:element name = "td">
                                                <xsl:attribute name = "class">top</xsl:attribute>
                                                <xsl:attribute name = "class">right</xsl:attribute>

                                                <xsl:call-template name = "number">
                                                        <xsl:with-param name = "num" select = "format-number(sum($lignes[not(cac:Item/cac:AdditionalItemProperty/cbc:Name/text() = 'TYPE_LIGNE' and (cac:Item/cac:AdditionalItemProperty/cbc:Value/text() = 'REGROUPEMENT' or cac:Item/cac:AdditionalItemProperty/cbc:Value/text() = 'INFORMATION'))]/cac:AllowanceCharge[cbc:ChargeIndicator='true']/cbc:Amount)-sum($lignes[not(cac:Item/cac:AdditionalItemProperty/cbc:Name/text() = 'TYPE_LIGNE' and (cac:Item/cac:AdditionalItemProperty/cbc:Value/text() = 'REGROUPEMENT' or cac:Item/cac:AdditionalItemProperty/cbc:Value/text() = 'INFORMATION'))]/cac:AllowanceCharge[cbc:ChargeIndicator='false']/cbc:Amount),'######0.0000;-#######.0000')"/>
                                                </xsl:call-template>
                                        </xsl:element>
                                </xsl:element>
                                <xsl:element name = "tr">
                                        <xsl:element name = "td">&nbsp;</xsl:element>
                                        <xsl:element name = "td">
                                                <xsl:attribute name = "class">top</xsl:attribute>
                                                <xsl:attribute name = "class">gras</xsl:attribute>
                                                <xsl:attribute name = "colspan">5</xsl:attribute>
                                                Net HT
                                        </xsl:element>
                                        <xsl:element name = "td">
                                                <xsl:attribute name = "class">top</xsl:attribute>
                                                <xsl:attribute name = "class">right</xsl:attribute>
                                                <xsl:call-template name = "number">
                                                        <xsl:with-param name = "num" select = "format-number(sum($lignes[not(cac:Item/cac:AdditionalItemProperty/cbc:Name/text() = 'TYPE_LIGNE' and (cac:Item/cac:AdditionalItemProperty/cbc:Value/text() = 'REGROUPEMENT' or cac:Item/cac:AdditionalItemProperty/cbc:Value/text() = 'INFORMATION'))]/cbc:LineExtensionAmount),'######0.0000;-#######.0000')"/>
                                                </xsl:call-template>
                                        </xsl:element>
                                </xsl:element>
                        </xsl:element>
                </xsl:element>
        </xsl:template>
        <xsl:template name = "PiedSite"></xsl:template>
        <xsl:template name = "PiedClient"></xsl:template>
        <xsl:template name = "PiedFournisseur">
                <xsl:param name = "eltPere"/>
                <xsl:element name = "br"/>
                <xsl:element name = "p">
                        <xsl:attribute name = "style">font-size: 10px</xsl:attribute>
                        <xsl:element name = "center">
                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:RegistrationName"/>
                                &nbsp;-
                                <xsl:for-each select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cac:AddressLine">
                                        &nbsp;
                                        <xsl:value-of select = "cbc:Line/text()"/>
                                </xsl:for-each>
                                
                                &nbsp; <xsl:value-of select="/inv:Invoice/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:StreetName"/>
                                
                                
                                &nbsp;-&nbsp;
                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:PostalZone"/>
                                &nbsp;
                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:CityName"/>

                                <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cac:Country/cbc:IdentificationCode">
                                        &nbsp;-&nbsp;
                                        <xsl:call-template name = "libPays">
                                                <xsl:with-param name = "cod" select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cac:Country/cbc:IdentificationCode"/>
                                        </xsl:call-template>
                                </xsl:if>
                                
                                <xsl:element name = "br"/>

                                <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:CorporateRegistrationScheme/cbc:ID">
                                        Capital social :&nbsp;
                                        <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:CorporateRegistrationScheme/cbc:ID/text()"/>
                                        &nbsp;-&nbsp;
                                </xsl:if>
                                <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cbc:CompanyID/text()"/>
                                <xsl:if test = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cbc:CompanyID">
                                        &nbsp;-&nbsp;
                                        Numéro de TVA intra-communautaire :
                                        &nbsp;:&nbsp;
                                        <xsl:value-of select = "$eltPere/cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cbc:CompanyID/text()"/>
                                </xsl:if>
                        </xsl:element>
                </xsl:element>
        </xsl:template>
        <xsl:template name = "PiedFacture"></xsl:template>
        <xsl:template name = "number">
                <xsl:param name = "num"/>
                <xsl:choose>
                        <xsl:when test = "string-length(string($num)) = 0"/>
                        <xsl:when test = "number($num) = 0">0,00</xsl:when>
                        <xsl:when test = "string(number($num)) = 'NaN'"/>

                        <xsl:when test = "string-length(substring-after(string($num), '.')) > 2">
                                 <xsl:value-of select = "format-number($num,'# ### ##0,00####;-# ### ###,00####','decformat')"/>
                         </xsl:when>
                        <xsl:otherwise>
                                <xsl:value-of select = "format-number($num,'# ### ##0,00;-# ### ###,00','decformat')"/>
                        </xsl:otherwise>
                </xsl:choose>
        </xsl:template>
        <xsl:template name = "initHtml">
                <xsl:param name = "eltPere"/>
                <html>
                        <head>
                                <xsl:choose>
                                        <xsl:when test="$eltPere/cac:InvoiceLine">
                                                <title>Facture Fournisseur</title>  
                                        </xsl:when>
                                        <xsl:otherwise>
                                                <title>Avoir Fournisseur</title>
                                        </xsl:otherwise>
                                </xsl:choose>
                                
                                <style type = "text/css" media = "print">
                                        .invoiceDiv {
                                        width: 100%;
                                        }
                                        @page portrait {
                                        size: 210mm 197mm;
                                        @bottom-center {
                                        content: "Page " counter(page);
                                        }
                                        }
                                </style>
                                <style type = "text/css" media = "screen">
                                        .invoiceDiv {
                                        width: 190mm;
                                        }
                                </style>
                                <style type = "text/css" media = "all">
                                        body, p, th, td {
                                        font-size: 10px;
                                        font-family: verdana, sans-serif;
                                        }
                                        .version {
                                        font-size: 10px;
                                        /* color:#FFFFFF; */
                                        }
                                        .titre0 {
                                        font-weight: bold;
                                        font-family: Arial, Helvetica, sans-serif;
                                        font-size: 20px;
                                        }
                                        .center {
                                        text-align: center;
                                        }
                                        .top {
                                        vertical-align: top;
                                        }
                                        .gras {
                                        font-weight: bold;
                                        }
                                        .italic {
                                        font-style: italic;
                                        }
                                        .normal {
                                        font-style: normal;
                                        font-weight: normal;
                                        }
                                        .right {
                                        text-align: right;
                                        }
                                        .bordered {
                                        border-style: solid;
                                        border-width: 1px;
                                        border-color: black;
                                        padding: 5px;
                                        }
                                        .collapsed {
                                        border-collapse: collapse;
                                        border-spacing: 0px;
                                        }
                                        .titre1 {
                                        margin-top: 12px;
                                        margin-bottom: 0px;
                                        font-wieght: bold;
                                        font-size: 16;
                                        }
                                        .nosign {
                                        list-style-type: none;
                                        }
                                        table.EnteteFournisseur {
                                        margin: 0;
                                        border-style: solid;
                                        border-width: 1px;
                                        border-color: black;
                                        width: 100%;
                                        font-size: 12px;
                                        text-align: left;
                                        padding: 0;
                                        page-break-inside: avoid;
                                        }
                                        th.EnteteFournisseur {
                                        font-size: 15px;
                                        text-align: left;
                                        padding: 5px;
                                        background-color: #999999;
                                        }
                                        td.EnteteFournisseur {
                                        font-size: 25px;
                                        text-align: left;
                                        padding: 5px;
                                        }
                                        table.EnteteClient {
                                        margin: 0;
                                        border-style: solid;
                                        border-width: 1px;
                                        border-color: black;
                                        width: 100%;
                                        font-size: 14px;
                                        text-align: left;
                                        padding: 0;
                                        page-break-inside: avoid;
                                        }
                                        th.EnteteClient {
                                        font-size: 15px;
                                        text-align: left;
                                        padding: 5px;
                                        background-color: #999999;
                                        }
                                        table.EnteteServiceRecepteur{
                                        margin:0;
                                        border-style:solid;
                                        border-width:1px;
                                        border-color:black;
                                        width:100%;
                                        font-size:14px;
                                        text-align:left;
                                        padding:0;
                                        page-break-inside:avoid;
                                        }
                                        th.EnteteServiceRecepteur{
                                        font-size:15px;
                                        text-align:left;
                                        padding:5px;
                                        background-color:#999999;
                                        }
                                        table.EnteteSite {
                                        border-style: solid;
                                        border-width: 1px;
                                        border-color: black;
                                        padding: 10px;
                                        margin: 0;
                                        width: 100%;
                                        font-size: 12px;
                                        text-align: left;
                                        page-break-inside: avoid;
                                        background-color: #999999;
                                        }
                                        table.Recapitulatif {
                                        border-style: none;
                                        padding: 10px;
                                        margin: 0;
                                        width: 100%;
                                        font-size: 12px;
                                        text-align: left;
                                        background-color: #f0f0f0;
                                        page-break-inside: avoid;
                                        }
                                        th.Recapitulatif {
                                        font-size: 15px;
                                        font-weight: bold;
                                        text-align: left;
                                        padding: 5px;
                                        }
                                        td.Recapitulatif {
                                        font-size: 13px;
                                        }
                                        table.RecapSousTotaux {
                                        margin: 0;
                                        border-style: solid;
                                        border-width: 1px;
                                        border-color: black;
                                        width: 100%;
                                        font-size: 10px;
                                        text-align: left;
                                        padding: 0;
                                        page-break-inside: avoid;
                                        }
                                        th.RecapSousTotaux {
                                        font-size: 10px;
                                        text-align: center;
                                        padding: 5px;
                                        border-style: solid;
                                        border-width: 1px;
                                        border-color: black;
                                        }
                                        td.RecapSousTotaux {
                                        font-size: 10px;
                                        text-align: left;
                                        padding: 5px;
                                        }
                                </style>
                        </head>
                        <body>
                                <span class = "version">Facture Fournisseur (FSO1100) : 20161214-01</span>

                                <xsl:for-each select = "$eltPere">
                                        <xsl:call-template name = "Entete">
                                                <xsl:with-param name="eltPere" select="$eltPere"/>
                                        </xsl:call-template>
                                        <xsl:call-template name = "EnteteFacture">
                                                <xsl:with-param name="eltPere" select="$eltPere"/>
                                        </xsl:call-template>
                                        
                                        <xsl:variable name = "nbDelivery" select = "count(cac:Delivery)"/>
                                        <xsl:if test = "$nbDelivery>1">
                                                <xsl:element name = "table">
                                                        <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                                        <xsl:element name = "tr">
                                                                <xsl:element name = "th">
                                                                        <xsl:attribute name = "class">Recapitulatif</xsl:attribute>
                                                                        Détails de facturation par site de livraison
                                                                </xsl:element>
                                                        </xsl:element>
                                                </xsl:element>
                                        </xsl:if>
                                        <xsl:for-each select = "$eltPere/cac:Delivery">
                                                <xsl:call-template name = "EnteteSite">
                                                        <xsl:with-param name = "site" select = "."/>
                                                        <xsl:with-param name = "nbSite" select = "$nbDelivery"/>
                                                </xsl:call-template>
												<xsl:choose>
													<xsl:when test="cac:DeliveryLocation/cbc:ID">
														<xsl:variable name = "SiteID1" select = "cac:DeliveryLocation/cbc:ID"/>
														<xsl:variable name = "lignes1" select = "$eltPere/cac:InvoiceLine[cac:Delivery/cbc:ID = $SiteID1]"/>
														<xsl:call-template name = "LigneFacture">
															<xsl:with-param name = "lignes" select = "$lignes1"/>
														</xsl:call-template>
													</xsl:when>
													<xsl:when test="cbc:ID">
														<xsl:variable name = "SiteID2" select = "cbc:ID"/>
														<xsl:variable name = "lignes2" select = "$eltPere/cac:InvoiceLine[cac:Delivery/cbc:ID = $SiteID2]"/>
														<xsl:call-template name = "LigneFacture">
															<xsl:with-param name = "lignes" select = "$lignes2"/>
														</xsl:call-template>
													</xsl:when>
												</xsl:choose>
                                        </xsl:for-each>
                                        <xsl:if test = "($eltPere/cac:InvoiceLine[not(cac:Delivery/cbc:ID=$eltPere/cac:Delivery/cac:DeliveryLocation/cbc:ID)] and $eltPere/cac:InvoiceLine[not(cac:Delivery/cbc:ID=$eltPere/cac:Delivery/cbc:ID)])">
                                              <xsl:call-template name = "EnteteSiteSansSite"/>
                                                <xsl:call-template name = "LigneFacture">
                                                        <xsl:with-param name = "lignes" select = "$eltPere/cac:InvoiceLine[not(cac:Delivery/cbc:ID=$eltPere/cac:Delivery/cac:DeliveryLocation/cbc:ID)and not(cac:Delivery/cbc:ID=$eltPere/cac:Delivery/cbc:ID)]"/>
                                                </xsl:call-template> 
                                        </xsl:if> 
                                        <xsl:if test = "$eltPere/cac:CreditNoteLine">
                                                <xsl:call-template name = "EnteteSiteSansSite"/>
                                                <xsl:call-template name = "LigneFacture">
                                                        <xsl:with-param name = "lignes" select = "$eltPere/cac:CreditNoteLine"/>
                                                </xsl:call-template>
                                        </xsl:if>
                                        
                                        <xsl:call-template name = "PiedClient"/>
                                        <xsl:call-template name = "PiedFournisseur">
                                                <xsl:with-param name="eltPere" select="$eltPere"/>
                                        </xsl:call-template>
                                </xsl:for-each>
                        </body>
                </html>
        </xsl:template>
        <xsl:template match = "/">
                <xsl:if test="/inv:Invoice">
                        <xsl:call-template name="initHtml">
                                <xsl:with-param name="eltPere" select="/inv:Invoice"/>
                        </xsl:call-template>
                </xsl:if>
                <xsl:if test="/avr:CreditNote">
                        <xsl:call-template name="initHtml">
                                <xsl:with-param name="eltPere" select="/avr:CreditNote"/>
                        </xsl:call-template>
                </xsl:if>
        </xsl:template>
</xsl:stylesheet>
